# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.user import User
    from datadog_api_client.v2.model.user_response_included_item import UserResponseIncludedItem
    from datadog_api_client.v2.model.organization import Organization
    from datadog_api_client.v2.model.permission import Permission
    from datadog_api_client.v2.model.role import Role


class UserResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.user import User
        from datadog_api_client.v2.model.user_response_included_item import UserResponseIncludedItem

        return {
            "data": (User,),
            "included": ([UserResponseIncludedItem],),
        }

    attribute_map = {
        "data": "data",
        "included": "included",
    }

    def __init__(
        self_,
        data: Union[User, UnsetType] = unset,
        included: Union[List[Union[UserResponseIncludedItem, Organization, Permission, Role]], UnsetType] = unset,
        **kwargs,
    ):
        """
        Response containing information about a single user.

        :param data: User object returned by the API.
        :type data: User, optional

        :param included: Array of objects related to the user.
        :type included: [UserResponseIncludedItem], optional
        """
        if data is not unset:
            kwargs["data"] = data
        if included is not unset:
            kwargs["included"] = included
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class FormulaAndFunctionEventAggregation(ModelSimple):
    """
    Aggregation methods for event platform queries.

    :param value: Must be one of ["count", "cardinality", "median", "pc75", "pc90", "pc95", "pc98", "pc99", "sum", "min", "max", "avg"].
    :type value: str
    """

    allowed_values = {
        "count",
        "cardinality",
        "median",
        "pc75",
        "pc90",
        "pc95",
        "pc98",
        "pc99",
        "sum",
        "min",
        "max",
        "avg",
    }
    COUNT: ClassVar["FormulaAndFunctionEventAggregation"]
    CARDINALITY: ClassVar["FormulaAndFunctionEventAggregation"]
    MEDIAN: ClassVar["FormulaAndFunctionEventAggregation"]
    PC75: ClassVar["FormulaAndFunctionEventAggregation"]
    PC90: ClassVar["FormulaAndFunctionEventAggregation"]
    PC95: ClassVar["FormulaAndFunctionEventAggregation"]
    PC98: ClassVar["FormulaAndFunctionEventAggregation"]
    PC99: ClassVar["FormulaAndFunctionEventAggregation"]
    SUM: ClassVar["FormulaAndFunctionEventAggregation"]
    MIN: ClassVar["FormulaAndFunctionEventAggregation"]
    MAX: ClassVar["FormulaAndFunctionEventAggregation"]
    AVG: ClassVar["FormulaAndFunctionEventAggregation"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


FormulaAndFunctionEventAggregation.COUNT = FormulaAndFunctionEventAggregation("count")
FormulaAndFunctionEventAggregation.CARDINALITY = FormulaAndFunctionEventAggregation("cardinality")
FormulaAndFunctionEventAggregation.MEDIAN = FormulaAndFunctionEventAggregation("median")
FormulaAndFunctionEventAggregation.PC75 = FormulaAndFunctionEventAggregation("pc75")
FormulaAndFunctionEventAggregation.PC90 = FormulaAndFunctionEventAggregation("pc90")
FormulaAndFunctionEventAggregation.PC95 = FormulaAndFunctionEventAggregation("pc95")
FormulaAndFunctionEventAggregation.PC98 = FormulaAndFunctionEventAggregation("pc98")
FormulaAndFunctionEventAggregation.PC99 = FormulaAndFunctionEventAggregation("pc99")
FormulaAndFunctionEventAggregation.SUM = FormulaAndFunctionEventAggregation("sum")
FormulaAndFunctionEventAggregation.MIN = FormulaAndFunctionEventAggregation("min")
FormulaAndFunctionEventAggregation.MAX = FormulaAndFunctionEventAggregation("max")
FormulaAndFunctionEventAggregation.AVG = FormulaAndFunctionEventAggregation("avg")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class ServiceCheckStatus(ModelSimple):
    """
    The status of a service check. Set to `0` for OK, `1` for warning, `2` for critical, and `3` for unknown.

    :param value: Must be one of [0, 1, 2, 3].
    :type value: int
    """

    allowed_values = {
        0,
        1,
        2,
        3,
    }
    OK: ClassVar["ServiceCheckStatus"]
    WARNING: ClassVar["ServiceCheckStatus"]
    CRITICAL: ClassVar["ServiceCheckStatus"]
    UNKNOWN: ClassVar["ServiceCheckStatus"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (int,),
        }


ServiceCheckStatus.OK = ServiceCheckStatus(0)
ServiceCheckStatus.WARNING = ServiceCheckStatus(1)
ServiceCheckStatus.CRITICAL = ServiceCheckStatus(2)
ServiceCheckStatus.UNKNOWN = ServiceCheckStatus(3)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.incident_field_attributes_single_value_type import (
        IncidentFieldAttributesSingleValueType,
    )


class IncidentFieldAttributesSingleValue(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.incident_field_attributes_single_value_type import (
            IncidentFieldAttributesSingleValueType,
        )

        return {
            "type": (IncidentFieldAttributesSingleValueType,),
            "value": (str, none_type),
        }

    attribute_map = {
        "type": "type",
        "value": "value",
    }

    def __init__(
        self_,
        type: Union[IncidentFieldAttributesSingleValueType, UnsetType] = unset,
        value: Union[str, none_type, UnsetType] = unset,
        **kwargs,
    ):
        """
        A field with a single value selected.

        :param type: Type of the single value field definitions.
        :type type: IncidentFieldAttributesSingleValueType, optional

        :param value: The single value selected for this field.
        :type value: str, none_type, optional
        """
        if type is not unset:
            kwargs["type"] = type
        if value is not unset:
            kwargs["value"] = value
        super().__init__(kwargs)



"""
Create a new dashboard with slo widget
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.slo_widget_definition import SLOWidgetDefinition
from datadog_api_client.v1.model.slo_widget_definition_type import SLOWidgetDefinitionType
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
from datadog_api_client.v1.model.widget_time_windows import WidgetTimeWindows
from datadog_api_client.v1.model.widget_view_mode import WidgetViewMode

# there is a valid "slo" in the system
SLO_DATA_0_ID = environ["SLO_DATA_0_ID"]

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_slo_widget",
    description="",
    widgets=[
        Widget(
            layout=WidgetLayout(
                x=0,
                y=0,
                width=60,
                height=21,
            ),
            definition=SLOWidgetDefinition(
                title_size="16",
                title_align=WidgetTextAlign.LEFT,
                type=SLOWidgetDefinitionType.SLO,
                view_type="detail",
                time_windows=[
                    WidgetTimeWindows.SEVEN_DAYS,
                ],
                slo_id=SLO_DATA_0_ID,
                show_error_budget=True,
                view_mode=WidgetViewMode.OVERALL,
                global_time_target="0",
            ),
        ),
    ],
    template_variables=[],
    layout_type=DashboardLayoutType.FREE,
    is_read_only=False,
    notify_list=[],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.timeseries_formula_request_attributes import TimeseriesFormulaRequestAttributes
    from datadog_api_client.v2.model.timeseries_formula_request_type import TimeseriesFormulaRequestType


class TimeseriesFormulaRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.timeseries_formula_request_attributes import TimeseriesFormulaRequestAttributes
        from datadog_api_client.v2.model.timeseries_formula_request_type import TimeseriesFormulaRequestType

        return {
            "attributes": (TimeseriesFormulaRequestAttributes,),
            "type": (TimeseriesFormulaRequestType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "type": "type",
    }

    def __init__(self_, attributes: TimeseriesFormulaRequestAttributes, type: TimeseriesFormulaRequestType, **kwargs):
        """
        A single timeseries query to be executed.

        :param attributes: The object describing a timeseries formula request.
        :type attributes: TimeseriesFormulaRequestAttributes

        :param type: The type of the resource. The value should always be timeseries_request.
        :type type: TimeseriesFormulaRequestType
        """
        super().__init__(kwargs)

        self_.attributes = attributes
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.log_content import LogContent


class Log(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.log_content import LogContent

        return {
            "content": (LogContent,),
            "id": (str,),
        }

    attribute_map = {
        "content": "content",
        "id": "id",
    }

    def __init__(self_, content: Union[LogContent, UnsetType] = unset, id: Union[str, UnsetType] = unset, **kwargs):
        """
        Object describing a log after being processed and stored by Datadog.

        :param content: JSON object containing all log attributes and their associated values.
        :type content: LogContent, optional

        :param id: Unique ID of the Log.
        :type id: str, optional
        """
        if content is not unset:
            kwargs["content"] = content
        if id is not unset:
            kwargs["id"] = id
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SensitiveDataScannerStandardPatternAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "name": (str,),
            "pattern": (str,),
            "tags": ([str],),
        }

    attribute_map = {
        "name": "name",
        "pattern": "pattern",
        "tags": "tags",
    }

    def __init__(
        self_,
        name: Union[str, UnsetType] = unset,
        pattern: Union[str, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes of the Sensitive Data Scanner standard pattern.

        :param name: Name of the standard pattern.
        :type name: str, optional

        :param pattern: Regex to match.
        :type pattern: str, optional

        :param tags: List of tags.
        :type tags: [str], optional
        """
        if name is not unset:
            kwargs["name"] = name
        if pattern is not unset:
            kwargs["pattern"] = pattern
        if tags is not unset:
            kwargs["tags"] = tags
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.aws_namespace import AWSNamespace


class AWSTagFilterCreateRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.aws_namespace import AWSNamespace

        return {
            "account_id": (str,),
            "namespace": (AWSNamespace,),
            "tag_filter_str": (str,),
        }

    attribute_map = {
        "account_id": "account_id",
        "namespace": "namespace",
        "tag_filter_str": "tag_filter_str",
    }

    def __init__(
        self_,
        account_id: Union[str, UnsetType] = unset,
        namespace: Union[AWSNamespace, UnsetType] = unset,
        tag_filter_str: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The objects used to set an AWS tag filter.

        :param account_id: Your AWS Account ID without dashes.
        :type account_id: str, optional

        :param namespace: The namespace associated with the tag filter entry.
        :type namespace: AWSNamespace, optional

        :param tag_filter_str: The tag filter string.
        :type tag_filter_str: str, optional
        """
        if account_id is not unset:
            kwargs["account_id"] = account_id
        if namespace is not unset:
            kwargs["namespace"] = namespace
        if tag_filter_str is not unset:
            kwargs["tag_filter_str"] = tag_filter_str
        super().__init__(kwargs)



"""
Create a new dashboard with slo list widget
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.slo_list_widget_definition import SLOListWidgetDefinition
from datadog_api_client.v1.model.slo_list_widget_definition_type import SLOListWidgetDefinitionType
from datadog_api_client.v1.model.slo_list_widget_query import SLOListWidgetQuery
from datadog_api_client.v1.model.slo_list_widget_request import SLOListWidgetRequest
from datadog_api_client.v1.model.slo_list_widget_request_type import SLOListWidgetRequestType
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_slo_list_widget",
    description="",
    widgets=[
        Widget(
            layout=WidgetLayout(
                x=0,
                y=0,
                width=60,
                height=21,
            ),
            definition=SLOListWidgetDefinition(
                title_size="16",
                title_align=WidgetTextAlign.LEFT,
                type=SLOListWidgetDefinitionType.SLO_LIST,
                requests=[
                    SLOListWidgetRequest(
                        query=SLOListWidgetQuery(
                            query_string="env:prod AND service:my-app",
                            limit=75,
                        ),
                        request_type=SLOListWidgetRequestType.SLO_LIST,
                    ),
                ],
            ),
        ),
    ],
    template_variables=[],
    layout_type=DashboardLayoutType.FREE,
    is_read_only=False,
    notify_list=[],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



"""
Cancel downtimes by scope returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.downtimes_api import DowntimesApi
from datadog_api_client.v1.model.cancel_downtimes_by_scope_request import CancelDowntimesByScopeRequest

# there is a valid "downtime" in the system
DOWNTIME_SCOPE_0 = environ["DOWNTIME_SCOPE_0"]

body = CancelDowntimesByScopeRequest(
    scope=DOWNTIME_SCOPE_0,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DowntimesApi(api_client)
    response = api_instance.cancel_downtimes_by_scope(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.usage_specified_custom_reports_attributes import (
        UsageSpecifiedCustomReportsAttributes,
    )
    from datadog_api_client.v1.model.usage_reports_type import UsageReportsType


class UsageSpecifiedCustomReportsData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.usage_specified_custom_reports_attributes import (
            UsageSpecifiedCustomReportsAttributes,
        )
        from datadog_api_client.v1.model.usage_reports_type import UsageReportsType

        return {
            "attributes": (UsageSpecifiedCustomReportsAttributes,),
            "id": (str,),
            "type": (UsageReportsType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "id": "id",
        "type": "type",
    }

    def __init__(
        self_,
        attributes: Union[UsageSpecifiedCustomReportsAttributes, UnsetType] = unset,
        id: Union[str, UnsetType] = unset,
        type: Union[UsageReportsType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Response containing date and type for specified custom reports.

        :param attributes: The response containing attributes for specified custom reports.
        :type attributes: UsageSpecifiedCustomReportsAttributes, optional

        :param id: The date for specified custom reports.
        :type id: str, optional

        :param type: The type of reports.
        :type type: UsageReportsType, optional
        """
        if attributes is not unset:
            kwargs["attributes"] = attributes
        if id is not unset:
            kwargs["id"] = id
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class FormulaAndFunctionApmResourceStatName(ModelSimple):
    """
    APM resource stat name.

    :param value: Must be one of ["errors", "error_rate", "hits", "latency_avg", "latency_distribution", "latency_max", "latency_p50", "latency_p75", "latency_p90", "latency_p95", "latency_p99"].
    :type value: str
    """

    allowed_values = {
        "errors",
        "error_rate",
        "hits",
        "latency_avg",
        "latency_distribution",
        "latency_max",
        "latency_p50",
        "latency_p75",
        "latency_p90",
        "latency_p95",
        "latency_p99",
    }
    ERRORS: ClassVar["FormulaAndFunctionApmResourceStatName"]
    ERROR_RATE: ClassVar["FormulaAndFunctionApmResourceStatName"]
    HITS: ClassVar["FormulaAndFunctionApmResourceStatName"]
    LATENCY_AVG: ClassVar["FormulaAndFunctionApmResourceStatName"]
    LATENCY_DISTRIBUTION: ClassVar["FormulaAndFunctionApmResourceStatName"]
    LATENCY_MAX: ClassVar["FormulaAndFunctionApmResourceStatName"]
    LATENCY_P50: ClassVar["FormulaAndFunctionApmResourceStatName"]
    LATENCY_P75: ClassVar["FormulaAndFunctionApmResourceStatName"]
    LATENCY_P90: ClassVar["FormulaAndFunctionApmResourceStatName"]
    LATENCY_P95: ClassVar["FormulaAndFunctionApmResourceStatName"]
    LATENCY_P99: ClassVar["FormulaAndFunctionApmResourceStatName"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


FormulaAndFunctionApmResourceStatName.ERRORS = FormulaAndFunctionApmResourceStatName("errors")
FormulaAndFunctionApmResourceStatName.ERROR_RATE = FormulaAndFunctionApmResourceStatName("error_rate")
FormulaAndFunctionApmResourceStatName.HITS = FormulaAndFunctionApmResourceStatName("hits")
FormulaAndFunctionApmResourceStatName.LATENCY_AVG = FormulaAndFunctionApmResourceStatName("latency_avg")
FormulaAndFunctionApmResourceStatName.LATENCY_DISTRIBUTION = FormulaAndFunctionApmResourceStatName(
    "latency_distribution"
)
FormulaAndFunctionApmResourceStatName.LATENCY_MAX = FormulaAndFunctionApmResourceStatName("latency_max")
FormulaAndFunctionApmResourceStatName.LATENCY_P50 = FormulaAndFunctionApmResourceStatName("latency_p50")
FormulaAndFunctionApmResourceStatName.LATENCY_P75 = FormulaAndFunctionApmResourceStatName("latency_p75")
FormulaAndFunctionApmResourceStatName.LATENCY_P90 = FormulaAndFunctionApmResourceStatName("latency_p90")
FormulaAndFunctionApmResourceStatName.LATENCY_P95 = FormulaAndFunctionApmResourceStatName("latency_p95")
FormulaAndFunctionApmResourceStatName.LATENCY_P99 = FormulaAndFunctionApmResourceStatName("latency_p99")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_test_details import SyntheticsTestDetails


class SyntheticsListTestsResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_test_details import SyntheticsTestDetails

        return {
            "tests": ([SyntheticsTestDetails],),
        }

    attribute_map = {
        "tests": "tests",
    }

    def __init__(self_, tests: Union[List[SyntheticsTestDetails], UnsetType] = unset, **kwargs):
        """
        Object containing an array of Synthetic tests configuration.

        :param tests: Array of Synthetic tests configuration.
        :type tests: [SyntheticsTestDetails], optional
        """
        if tests is not unset:
            kwargs["tests"] = tests
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_browser_error_type import SyntheticsBrowserErrorType


class SyntheticsBrowserError(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_browser_error_type import SyntheticsBrowserErrorType

        return {
            "description": (str,),
            "name": (str,),
            "status": (int,),
            "type": (SyntheticsBrowserErrorType,),
        }

    attribute_map = {
        "description": "description",
        "name": "name",
        "status": "status",
        "type": "type",
    }

    def __init__(
        self_,
        description: str,
        name: str,
        type: SyntheticsBrowserErrorType,
        status: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Error response object for a browser test.

        :param description: Description of the error.
        :type description: str

        :param name: Name of the error.
        :type name: str

        :param status: Status Code of the error.
        :type status: int, optional

        :param type: Error type returned by a browser test.
        :type type: SyntheticsBrowserErrorType
        """
        if status is not unset:
            kwargs["status"] = status
        super().__init__(kwargs)

        self_.description = description
        self_.name = name
        self_.type = type



"""
Submit metrics returns "Payload accepted" response
"""

from datetime import datetime
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.metrics_api import MetricsApi
from datadog_api_client.v1.model.metrics_payload import MetricsPayload
from datadog_api_client.v1.model.point import Point
from datadog_api_client.v1.model.series import Series

body = MetricsPayload(
    series=[
        Series(
            metric="system.load.1",
            type="gauge",
            points=[
                Point(
                    [
                        datetime.now().timestamp(),
                        1.1,
                    ]
                ),
            ],
            tags=[
                "test:ExampleSubmitmetricsreturnsPayloadacceptedresponse",
            ],
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    response = api_instance.submit_metrics(body=body)

    print(response)



"""
Check permissions for log services returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.aws_logs_integration_api import AWSLogsIntegrationApi
from datadog_api_client.v1.model.aws_logs_services_request import AWSLogsServicesRequest

body = AWSLogsServicesRequest(
    account_id="1234567",
    services=[
        "s3",
        "elb",
        "elbv2",
        "cloudfront",
        "redshift",
        "lambda",
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = AWSLogsIntegrationApi(api_client)
    response = api_instance.check_aws_logs_services_async(body=body)

    print(response)



"""
Search Audit Logs events returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.audit_api import AuditApi
from datadog_api_client.v2.model.audit_logs_query_filter import AuditLogsQueryFilter
from datadog_api_client.v2.model.audit_logs_query_options import AuditLogsQueryOptions
from datadog_api_client.v2.model.audit_logs_query_page_options import AuditLogsQueryPageOptions
from datadog_api_client.v2.model.audit_logs_search_events_request import AuditLogsSearchEventsRequest
from datadog_api_client.v2.model.audit_logs_sort import AuditLogsSort

body = AuditLogsSearchEventsRequest(
    filter=AuditLogsQueryFilter(
        _from="now-15m",
        query="@type:session AND @session.type:user",
        to="now",
    ),
    options=AuditLogsQueryOptions(
        time_offset=0,
        timezone="GMT",
    ),
    page=AuditLogsQueryPageOptions(
        limit=25,
    ),
    sort=AuditLogsSort.TIMESTAMP_ASCENDING,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = AuditApi(api_client)
    response = api_instance.search_audit_logs(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.i_frame_widget_definition_type import IFrameWidgetDefinitionType


class IFrameWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.i_frame_widget_definition_type import IFrameWidgetDefinitionType

        return {
            "type": (IFrameWidgetDefinitionType,),
            "url": (str,),
        }

    attribute_map = {
        "type": "type",
        "url": "url",
    }

    def __init__(self_, type: IFrameWidgetDefinitionType, url: str, **kwargs):
        """
        The iframe widget allows you to embed a portion of any other web page on your dashboard. Only available on FREE layout dashboards.

        :param type: Type of the iframe widget.
        :type type: IFrameWidgetDefinitionType

        :param url: URL of the iframe.
        :type url: str
        """
        super().__init__(kwargs)

        self_.type = type
        self_.url = url



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.cloud_configuration_rego_rule import CloudConfigurationRegoRule


class CloudConfigurationComplianceRuleOptions(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.cloud_configuration_rego_rule import CloudConfigurationRegoRule

        return {
            "complex_rule": (bool,),
            "rego_rule": (CloudConfigurationRegoRule,),
            "resource_type": (str,),
        }

    attribute_map = {
        "complex_rule": "complexRule",
        "rego_rule": "regoRule",
        "resource_type": "resourceType",
    }

    def __init__(
        self_,
        complex_rule: Union[bool, UnsetType] = unset,
        rego_rule: Union[CloudConfigurationRegoRule, UnsetType] = unset,
        resource_type: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Options for cloud_configuration rules.
        Fields ``resourceType`` and ``regoRule`` are mandatory when managing custom ``cloud_configuration`` rules.

        :param complex_rule: Whether the rule is a complex one.
            Must be set to true if ``regoRule.resourceTypes`` contains more than one item. Defaults to false.
        :type complex_rule: bool, optional

        :param rego_rule: Rule details.
        :type rego_rule: CloudConfigurationRegoRule, optional

        :param resource_type: Main resource type to be checked by the rule. It should be specified again in ``regoRule.resourceTypes``.
        :type resource_type: str, optional
        """
        if complex_rule is not unset:
            kwargs["complex_rule"] = complex_rule
        if rego_rule is not unset:
            kwargs["rego_rule"] = rego_rule
        if resource_type is not unset:
            kwargs["resource_type"] = resource_type
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    file_type,
)


class IdpFormData(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "idp_file": (file_type,),
        }

    attribute_map = {
        "idp_file": "idp_file",
    }

    def __init__(self_, idp_file: file_type, **kwargs):
        """
        Object describing the IdP configuration.

        :param idp_file: The path to the XML metadata file you wish to upload.
        :type idp_file: file_type
        """
        super().__init__(kwargs)

        self_.idp_file = idp_file



"""
Update a cloud configuration rule's details returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi
from datadog_api_client.v2.model.cloud_configuration_compliance_rule_options import (
    CloudConfigurationComplianceRuleOptions,
)
from datadog_api_client.v2.model.cloud_configuration_rego_rule import CloudConfigurationRegoRule
from datadog_api_client.v2.model.cloud_configuration_rule_compliance_signal_options import (
    CloudConfigurationRuleComplianceSignalOptions,
)
from datadog_api_client.v2.model.security_monitoring_rule_case import SecurityMonitoringRuleCase
from datadog_api_client.v2.model.security_monitoring_rule_options import SecurityMonitoringRuleOptions
from datadog_api_client.v2.model.security_monitoring_rule_severity import SecurityMonitoringRuleSeverity
from datadog_api_client.v2.model.security_monitoring_rule_update_payload import SecurityMonitoringRuleUpdatePayload

# there is a valid "cloud_configuration_rule" in the system
CLOUD_CONFIGURATION_RULE_ID = environ["CLOUD_CONFIGURATION_RULE_ID"]

body = SecurityMonitoringRuleUpdatePayload(
    name="Example-Update_a_cloud_configuration_rule_s_details_returns_OK_response_cloud_updated",
    is_enabled=False,
    cases=[
        SecurityMonitoringRuleCase(
            status=SecurityMonitoringRuleSeverity.INFO,
            notifications=[],
        ),
    ],
    options=SecurityMonitoringRuleOptions(
        compliance_rule_options=CloudConfigurationComplianceRuleOptions(
            resource_type="gcp_compute_disk",
            rego_rule=CloudConfigurationRegoRule(
                policy="package datadog\n",
                resource_types=[
                    "gcp_compute_disk",
                ],
            ),
        ),
    ),
    message="ddd",
    tags=[],
    compliance_signal_options=CloudConfigurationRuleComplianceSignalOptions(
        user_activation_status=False,
        user_group_by_fields=[],
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    response = api_instance.update_security_monitoring_rule(rule_id=CLOUD_CONFIGURATION_RULE_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.table_widget_cell_display_mode import TableWidgetCellDisplayMode
    from datadog_api_client.v1.model.widget_conditional_format import WidgetConditionalFormat
    from datadog_api_client.v1.model.widget_formula_limit import WidgetFormulaLimit
    from datadog_api_client.v1.model.widget_formula_style import WidgetFormulaStyle


class WidgetFormula(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.table_widget_cell_display_mode import TableWidgetCellDisplayMode
        from datadog_api_client.v1.model.widget_conditional_format import WidgetConditionalFormat
        from datadog_api_client.v1.model.widget_formula_limit import WidgetFormulaLimit
        from datadog_api_client.v1.model.widget_formula_style import WidgetFormulaStyle

        return {
            "alias": (str,),
            "cell_display_mode": (TableWidgetCellDisplayMode,),
            "conditional_formats": ([WidgetConditionalFormat],),
            "formula": (str,),
            "limit": (WidgetFormulaLimit,),
            "style": (WidgetFormulaStyle,),
        }

    attribute_map = {
        "alias": "alias",
        "cell_display_mode": "cell_display_mode",
        "conditional_formats": "conditional_formats",
        "formula": "formula",
        "limit": "limit",
        "style": "style",
    }

    def __init__(
        self_,
        formula: str,
        alias: Union[str, UnsetType] = unset,
        cell_display_mode: Union[TableWidgetCellDisplayMode, UnsetType] = unset,
        conditional_formats: Union[List[WidgetConditionalFormat], UnsetType] = unset,
        limit: Union[WidgetFormulaLimit, UnsetType] = unset,
        style: Union[WidgetFormulaStyle, UnsetType] = unset,
        **kwargs,
    ):
        """
        Formula to be used in a widget query.

        :param alias: Expression alias.
        :type alias: str, optional

        :param cell_display_mode: Define a display mode for the table cell.
        :type cell_display_mode: TableWidgetCellDisplayMode, optional

        :param conditional_formats: List of conditional formats.
        :type conditional_formats: [WidgetConditionalFormat], optional

        :param formula: String expression built from queries, formulas, and functions.
        :type formula: str

        :param limit: Options for limiting results returned.
        :type limit: WidgetFormulaLimit, optional

        :param style: Styling options for widget formulas.
        :type style: WidgetFormulaStyle, optional
        """
        if alias is not unset:
            kwargs["alias"] = alias
        if cell_display_mode is not unset:
            kwargs["cell_display_mode"] = cell_display_mode
        if conditional_formats is not unset:
            kwargs["conditional_formats"] = conditional_formats
        if limit is not unset:
            kwargs["limit"] = limit
        if style is not unset:
            kwargs["style"] = style
        super().__init__(kwargs)

        self_.formula = formula



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.alert_value_widget_definition_type import AlertValueWidgetDefinitionType


class AlertValueWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.alert_value_widget_definition_type import AlertValueWidgetDefinitionType

        return {
            "alert_id": (str,),
            "precision": (int,),
            "text_align": (WidgetTextAlign,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (AlertValueWidgetDefinitionType,),
            "unit": (str,),
        }

    attribute_map = {
        "alert_id": "alert_id",
        "precision": "precision",
        "text_align": "text_align",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
        "unit": "unit",
    }

    def __init__(
        self_,
        alert_id: str,
        type: AlertValueWidgetDefinitionType,
        precision: Union[int, UnsetType] = unset,
        text_align: Union[WidgetTextAlign, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        unit: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Alert values are query values showing the current value of the metric in any monitor defined on your system.

        :param alert_id: ID of the alert to use in the widget.
        :type alert_id: str

        :param precision: Number of decimal to show. If not defined, will use the raw value.
        :type precision: int, optional

        :param text_align: How to align the text on the widget.
        :type text_align: WidgetTextAlign, optional

        :param title: Title of the widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of value in the widget.
        :type title_size: str, optional

        :param type: Type of the alert value widget.
        :type type: AlertValueWidgetDefinitionType

        :param unit: Unit to display with the value.
        :type unit: str, optional
        """
        if precision is not unset:
            kwargs["precision"] = precision
        if text_align is not unset:
            kwargs["text_align"] = text_align
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        if unit is not unset:
            kwargs["unit"] = unit
        super().__init__(kwargs)

        self_.alert_id = alert_id
        self_.type = type



"""
Get all users of a role returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.roles_api import RolesApi

# there is a valid "role" in the system
ROLE_DATA_ID = environ["ROLE_DATA_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = RolesApi(api_client)
    response = api_instance.list_role_users(
        role_id=ROLE_DATA_ID,
    )

    print(response)



"""
Create role returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.roles_api import RolesApi
from datadog_api_client.v2.model.role_create_attributes import RoleCreateAttributes
from datadog_api_client.v2.model.role_create_data import RoleCreateData
from datadog_api_client.v2.model.role_create_request import RoleCreateRequest
from datadog_api_client.v2.model.roles_type import RolesType

body = RoleCreateRequest(
    data=RoleCreateData(
        type=RolesType.ROLES,
        attributes=RoleCreateAttributes(
            name="Example-Create_role_returns_OK_response",
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = RolesApi(api_client)
    response = api_instance.create_role(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.logs_query_filter import LogsQueryFilter
    from datadog_api_client.v2.model.logs_query_options import LogsQueryOptions
    from datadog_api_client.v2.model.logs_list_request_page import LogsListRequestPage
    from datadog_api_client.v2.model.logs_sort import LogsSort


class LogsListRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.logs_query_filter import LogsQueryFilter
        from datadog_api_client.v2.model.logs_query_options import LogsQueryOptions
        from datadog_api_client.v2.model.logs_list_request_page import LogsListRequestPage
        from datadog_api_client.v2.model.logs_sort import LogsSort

        return {
            "filter": (LogsQueryFilter,),
            "options": (LogsQueryOptions,),
            "page": (LogsListRequestPage,),
            "sort": (LogsSort,),
        }

    attribute_map = {
        "filter": "filter",
        "options": "options",
        "page": "page",
        "sort": "sort",
    }

    def __init__(
        self_,
        filter: Union[LogsQueryFilter, UnsetType] = unset,
        options: Union[LogsQueryOptions, UnsetType] = unset,
        page: Union[LogsListRequestPage, UnsetType] = unset,
        sort: Union[LogsSort, UnsetType] = unset,
        **kwargs,
    ):
        """
        The request for a logs list.

        :param filter: The search and filter query settings
        :type filter: LogsQueryFilter, optional

        :param options: Global query options that are used during the query.
            Note: You should only supply timezone or time offset but not both otherwise the query will fail.
        :type options: LogsQueryOptions, optional

        :param page: Paging attributes for listing logs.
        :type page: LogsListRequestPage, optional

        :param sort: Sort parameters when querying logs.
        :type sort: LogsSort, optional
        """
        if filter is not unset:
            kwargs["filter"] = filter
        if options is not unset:
            kwargs["options"] = options
        if page is not unset:
            kwargs["page"] = page
        if sort is not unset:
            kwargs["sort"] = sort
        super().__init__(kwargs)



"""
Create an API key returns "Created" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.key_management_api import KeyManagementApi
from datadog_api_client.v2.model.api_key_create_attributes import APIKeyCreateAttributes
from datadog_api_client.v2.model.api_key_create_data import APIKeyCreateData
from datadog_api_client.v2.model.api_key_create_request import APIKeyCreateRequest
from datadog_api_client.v2.model.api_keys_type import APIKeysType

body = APIKeyCreateRequest(
    data=APIKeyCreateData(
        type=APIKeysType.API_KEYS,
        attributes=APIKeyCreateAttributes(
            name="Example-Create_an_API_key_returns_Created_response",
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = KeyManagementApi(api_client)
    response = api_instance.create_api_key(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.monitor_options_aggregation import MonitorOptionsAggregation
    from datadog_api_client.v1.model.monitor_device_id import MonitorDeviceID
    from datadog_api_client.v1.model.on_missing_data_option import OnMissingDataOption
    from datadog_api_client.v1.model.monitor_renotify_status_type import MonitorRenotifyStatusType
    from datadog_api_client.v1.model.monitor_options_scheduling_options import MonitorOptionsSchedulingOptions
    from datadog_api_client.v1.model.monitor_threshold_window_options import MonitorThresholdWindowOptions
    from datadog_api_client.v1.model.monitor_thresholds import MonitorThresholds
    from datadog_api_client.v1.model.monitor_formula_and_function_query_definition import (
        MonitorFormulaAndFunctionQueryDefinition,
    )
    from datadog_api_client.v1.model.monitor_formula_and_function_event_query_definition import (
        MonitorFormulaAndFunctionEventQueryDefinition,
    )


class MonitorOptions(ModelNormal):
    validations = {
        "min_failure_duration": {
            "inclusive_maximum": 7200,
            "inclusive_minimum": 0,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.monitor_options_aggregation import MonitorOptionsAggregation
        from datadog_api_client.v1.model.monitor_device_id import MonitorDeviceID
        from datadog_api_client.v1.model.on_missing_data_option import OnMissingDataOption
        from datadog_api_client.v1.model.monitor_renotify_status_type import MonitorRenotifyStatusType
        from datadog_api_client.v1.model.monitor_options_scheduling_options import MonitorOptionsSchedulingOptions
        from datadog_api_client.v1.model.monitor_threshold_window_options import MonitorThresholdWindowOptions
        from datadog_api_client.v1.model.monitor_thresholds import MonitorThresholds
        from datadog_api_client.v1.model.monitor_formula_and_function_query_definition import (
            MonitorFormulaAndFunctionQueryDefinition,
        )

        return {
            "aggregation": (MonitorOptionsAggregation,),
            "device_ids": ([MonitorDeviceID],),
            "enable_logs_sample": (bool,),
            "enable_samples": (bool,),
            "escalation_message": (str,),
            "evaluation_delay": (int, none_type),
            "group_retention_duration": (str,),
            "groupby_simple_monitor": (bool,),
            "include_tags": (bool,),
            "locked": (bool,),
            "min_failure_duration": (int, none_type),
            "min_location_failed": (int, none_type),
            "new_group_delay": (int, none_type),
            "new_host_delay": (int, none_type),
            "no_data_timeframe": (int, none_type),
            "notify_audit": (bool,),
            "notify_by": ([str],),
            "notify_no_data": (bool,),
            "on_missing_data": (OnMissingDataOption,),
            "renotify_interval": (int, none_type),
            "renotify_occurrences": (int, none_type),
            "renotify_statuses": ([MonitorRenotifyStatusType], none_type),
            "require_full_window": (bool,),
            "scheduling_options": (MonitorOptionsSchedulingOptions,),
            "silenced": (
                {
                    str: (
                        int,
                        none_type,
                    )
                },
            ),
            "synthetics_check_id": (str, none_type),
            "threshold_windows": (MonitorThresholdWindowOptions,),
            "thresholds": (MonitorThresholds,),
            "timeout_h": (int, none_type),
            "variables": ([MonitorFormulaAndFunctionQueryDefinition],),
        }

    attribute_map = {
        "aggregation": "aggregation",
        "device_ids": "device_ids",
        "enable_logs_sample": "enable_logs_sample",
        "enable_samples": "enable_samples",
        "escalation_message": "escalation_message",
        "evaluation_delay": "evaluation_delay",
        "group_retention_duration": "group_retention_duration",
        "groupby_simple_monitor": "groupby_simple_monitor",
        "include_tags": "include_tags",
        "locked": "locked",
        "min_failure_duration": "min_failure_duration",
        "min_location_failed": "min_location_failed",
        "new_group_delay": "new_group_delay",
        "new_host_delay": "new_host_delay",
        "no_data_timeframe": "no_data_timeframe",
        "notify_audit": "notify_audit",
        "notify_by": "notify_by",
        "notify_no_data": "notify_no_data",
        "on_missing_data": "on_missing_data",
        "renotify_interval": "renotify_interval",
        "renotify_occurrences": "renotify_occurrences",
        "renotify_statuses": "renotify_statuses",
        "require_full_window": "require_full_window",
        "scheduling_options": "scheduling_options",
        "silenced": "silenced",
        "synthetics_check_id": "synthetics_check_id",
        "threshold_windows": "threshold_windows",
        "thresholds": "thresholds",
        "timeout_h": "timeout_h",
        "variables": "variables",
    }
    read_only_vars = {
        "aggregation",
        "device_ids",
    }

    def __init__(
        self_,
        aggregation: Union[MonitorOptionsAggregation, UnsetType] = unset,
        device_ids: Union[List[MonitorDeviceID], UnsetType] = unset,
        enable_logs_sample: Union[bool, UnsetType] = unset,
        enable_samples: Union[bool, UnsetType] = unset,
        escalation_message: Union[str, UnsetType] = unset,
        evaluation_delay: Union[int, none_type, UnsetType] = unset,
        group_retention_duration: Union[str, UnsetType] = unset,
        groupby_simple_monitor: Union[bool, UnsetType] = unset,
        include_tags: Union[bool, UnsetType] = unset,
        locked: Union[bool, UnsetType] = unset,
        min_failure_duration: Union[int, none_type, UnsetType] = unset,
        min_location_failed: Union[int, none_type, UnsetType] = unset,
        new_group_delay: Union[int, none_type, UnsetType] = unset,
        new_host_delay: Union[int, none_type, UnsetType] = unset,
        no_data_timeframe: Union[int, none_type, UnsetType] = unset,
        notify_audit: Union[bool, UnsetType] = unset,
        notify_by: Union[List[str], UnsetType] = unset,
        notify_no_data: Union[bool, UnsetType] = unset,
        on_missing_data: Union[OnMissingDataOption, UnsetType] = unset,
        renotify_interval: Union[int, none_type, UnsetType] = unset,
        renotify_occurrences: Union[int, none_type, UnsetType] = unset,
        renotify_statuses: Union[List[MonitorRenotifyStatusType], none_type, UnsetType] = unset,
        require_full_window: Union[bool, UnsetType] = unset,
        scheduling_options: Union[MonitorOptionsSchedulingOptions, UnsetType] = unset,
        silenced: Union[Dict[str, Union[int, none_type]], UnsetType] = unset,
        synthetics_check_id: Union[str, none_type, UnsetType] = unset,
        threshold_windows: Union[MonitorThresholdWindowOptions, UnsetType] = unset,
        thresholds: Union[MonitorThresholds, UnsetType] = unset,
        timeout_h: Union[int, none_type, UnsetType] = unset,
        variables: Union[
            List[Union[MonitorFormulaAndFunctionQueryDefinition, MonitorFormulaAndFunctionEventQueryDefinition]],
            UnsetType,
        ] = unset,
        **kwargs,
    ):
        """
        List of options associated with your monitor.

        :param aggregation: Type of aggregation performed in the monitor query.
        :type aggregation: MonitorOptionsAggregation, optional

        :param device_ids: IDs of the device the Synthetics monitor is running on. **Deprecated**.
        :type device_ids: [MonitorDeviceID], optional

        :param enable_logs_sample: Whether or not to send a log sample when the log monitor triggers.
        :type enable_logs_sample: bool, optional

        :param enable_samples: Whether or not to send a list of samples when the monitor triggers. This is only used by CI Test and Pipeline monitors.
        :type enable_samples: bool, optional

        :param escalation_message: We recommend using the `is_renotify <https://docs.datadoghq.com/monitors/notify/?tab=is_alert#renotify>`_ ,
            block in the original message instead.
            A message to include with a re-notification. Supports the ``@username`` notification we allow elsewhere.
            Not applicable if ``renotify_interval`` is ``None``.
        :type escalation_message: str, optional

        :param evaluation_delay: Time (in seconds) to delay evaluation, as a non-negative integer. For example, if the value is set to ``300`` (5min),
            the timeframe is set to ``last_5m`` and the time is 7:00, the monitor evaluates data from 6:50 to 6:55.
            This is useful for AWS CloudWatch and other backfilled metrics to ensure the monitor always has data during evaluation.
        :type evaluation_delay: int, none_type, optional

        :param group_retention_duration: The time span after which groups with missing data are dropped from the monitor state.
            The minimum value is one hour, and the maximum value is 72 hours.
            Example values are: "60m", "1h", and "2d".
            This option is only available for APM Trace Analytics, Audit Trail, CI, Error Tracking, Event, Logs, and RUM monitors.
        :type group_retention_duration: str, optional

        :param groupby_simple_monitor: Whether the log alert monitor triggers a single alert or multiple alerts when any group breaches a threshold.
        :type groupby_simple_monitor: bool, optional

        :param include_tags: A Boolean indicating whether notifications from this monitor automatically inserts its triggering tags into the title.

            **Examples**

            * If ``True`` , ``[Triggered on {host:h1}] Monitor Title``
            * If ``False`` , ``[Triggered] Monitor Title``
        :type include_tags: bool, optional

        :param locked: Whether or not the monitor is locked (only editable by creator and admins). Use ``restricted_roles`` instead. **Deprecated**.
        :type locked: bool, optional

        :param min_failure_duration: How long the test should be in failure before alerting (integer, number of seconds, max 7200).
        :type min_failure_duration: int, none_type, optional

        :param min_location_failed: The minimum number of locations in failure at the same time during
            at least one moment in the ``min_failure_duration`` period ( ``min_location_failed`` and ``min_failure_duration``
            are part of the advanced alerting rules - integer, >= 1).
        :type min_location_failed: int, none_type, optional

        :param new_group_delay: Time (in seconds) to skip evaluations for new groups.

            For example, this option can be used to skip evaluations for new hosts while they initialize.

            Must be a non negative integer.
        :type new_group_delay: int, none_type, optional

        :param new_host_delay: Time (in seconds) to allow a host to boot and applications
            to fully start before starting the evaluation of monitor results.
            Should be a non negative integer.

            Use new_group_delay instead. **Deprecated**.
        :type new_host_delay: int, none_type, optional

        :param no_data_timeframe: The number of minutes before a monitor notifies after data stops reporting.
            Datadog recommends at least 2x the monitor timeframe for query alerts or 2 minutes for service checks.
            If omitted, 2x the evaluation timeframe is used for query alerts, and 24 hours is used for service checks.
        :type no_data_timeframe: int, none_type, optional

        :param notify_audit: A Boolean indicating whether tagged users is notified on changes to this monitor.
        :type notify_audit: bool, optional

        :param notify_by: Controls what granularity a monitor alerts on. Only available for monitors with groupings.
            For instance, a monitor grouped by ``cluster`` , ``namespace`` , and ``pod`` can be configured to only notify on each
            new ``cluster`` violating the alert conditions by setting ``notify_by`` to ``["cluster"]``. Tags mentioned
            in ``notify_by`` must be a subset of the grouping tags in the query.
            For example, a query grouped by ``cluster`` and ``namespace`` cannot notify on ``region``.
            Setting ``notify_by`` to ``[*]`` configures the monitor to notify as a simple-alert.
        :type notify_by: [str], optional

        :param notify_no_data: A Boolean indicating whether this monitor notifies when data stops reporting.
        :type notify_no_data: bool, optional

        :param on_missing_data: Controls how groups or monitors are treated if an evaluation does not return any data points.
            The default option results in different behavior depending on the monitor query type.
            For monitors using Count queries, an empty monitor evaluation is treated as 0 and is compared to the threshold conditions.
            For monitors using any query type other than Count, for example Gauge, Measure, or Rate, the monitor shows the last known status.
            This option is only available for APM Trace Analytics, Audit Trail, CI, Error Tracking, Event, Logs, and RUM monitors.
        :type on_missing_data: OnMissingDataOption, optional

        :param renotify_interval: The number of minutes after the last notification before a monitor re-notifies on the current status.
            It only re-notifies if it’s not resolved.
        :type renotify_interval: int, none_type, optional

        :param renotify_occurrences: The number of times re-notification messages should be sent on the current status at the provided re-notification interval.
        :type renotify_occurrences: int, none_type, optional

        :param renotify_statuses: The types of monitor statuses for which re-notification messages are sent.
        :type renotify_statuses: [MonitorRenotifyStatusType], none_type, optional

        :param require_full_window: A Boolean indicating whether this monitor needs a full window of data before it’s evaluated.
            We highly recommend you set this to ``false`` for sparse metrics,
            otherwise some evaluations are skipped. Default is false.
        :type require_full_window: bool, optional

        :param scheduling_options: Configuration options for scheduling.
        :type scheduling_options: MonitorOptionsSchedulingOptions, optional

        :param silenced: Information about the downtime applied to the monitor. **Deprecated**.
        :type silenced: {str: (int, none_type,)}, optional

        :param synthetics_check_id: ID of the corresponding Synthetic check. **Deprecated**.
        :type synthetics_check_id: str, none_type, optional

        :param threshold_windows: Alerting time window options.
        :type threshold_windows: MonitorThresholdWindowOptions, optional

        :param thresholds: List of the different monitor threshold available.
        :type thresholds: MonitorThresholds, optional

        :param timeout_h: The number of hours of the monitor not reporting data before it automatically resolves from a triggered state. The minimum allowed value is 0 hours. The maximum allowed value is 24 hours.
        :type timeout_h: int, none_type, optional

        :param variables: List of requests that can be used in the monitor query. **This feature is currently in beta.**
        :type variables: [MonitorFormulaAndFunctionQueryDefinition], optional
        """
        if aggregation is not unset:
            kwargs["aggregation"] = aggregation
        if device_ids is not unset:
            kwargs["device_ids"] = device_ids
        if enable_logs_sample is not unset:
            kwargs["enable_logs_sample"] = enable_logs_sample
        if enable_samples is not unset:
            kwargs["enable_samples"] = enable_samples
        if escalation_message is not unset:
            kwargs["escalation_message"] = escalation_message
        if evaluation_delay is not unset:
            kwargs["evaluation_delay"] = evaluation_delay
        if group_retention_duration is not unset:
            kwargs["group_retention_duration"] = group_retention_duration
        if groupby_simple_monitor is not unset:
            kwargs["groupby_simple_monitor"] = groupby_simple_monitor
        if include_tags is not unset:
            kwargs["include_tags"] = include_tags
        if locked is not unset:
            kwargs["locked"] = locked
        if min_failure_duration is not unset:
            kwargs["min_failure_duration"] = min_failure_duration
        if min_location_failed is not unset:
            kwargs["min_location_failed"] = min_location_failed
        if new_group_delay is not unset:
            kwargs["new_group_delay"] = new_group_delay
        if new_host_delay is not unset:
            kwargs["new_host_delay"] = new_host_delay
        if no_data_timeframe is not unset:
            kwargs["no_data_timeframe"] = no_data_timeframe
        if notify_audit is not unset:
            kwargs["notify_audit"] = notify_audit
        if notify_by is not unset:
            kwargs["notify_by"] = notify_by
        if notify_no_data is not unset:
            kwargs["notify_no_data"] = notify_no_data
        if on_missing_data is not unset:
            kwargs["on_missing_data"] = on_missing_data
        if renotify_interval is not unset:
            kwargs["renotify_interval"] = renotify_interval
        if renotify_occurrences is not unset:
            kwargs["renotify_occurrences"] = renotify_occurrences
        if renotify_statuses is not unset:
            kwargs["renotify_statuses"] = renotify_statuses
        if require_full_window is not unset:
            kwargs["require_full_window"] = require_full_window
        if scheduling_options is not unset:
            kwargs["scheduling_options"] = scheduling_options
        if silenced is not unset:
            kwargs["silenced"] = silenced
        if synthetics_check_id is not unset:
            kwargs["synthetics_check_id"] = synthetics_check_id
        if threshold_windows is not unset:
            kwargs["threshold_windows"] = threshold_windows
        if thresholds is not unset:
            kwargs["thresholds"] = thresholds
        if timeout_h is not unset:
            kwargs["timeout_h"] = timeout_h
        if variables is not unset:
            kwargs["variables"] = variables
        super().__init__(kwargs)



"""
Create a detection rule with type 'signal_correlation' returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi
from datadog_api_client.v2.model.security_monitoring_rule_case_create import SecurityMonitoringRuleCaseCreate
from datadog_api_client.v2.model.security_monitoring_rule_evaluation_window import (
    SecurityMonitoringRuleEvaluationWindow,
)
from datadog_api_client.v2.model.security_monitoring_rule_keep_alive import SecurityMonitoringRuleKeepAlive
from datadog_api_client.v2.model.security_monitoring_rule_max_signal_duration import (
    SecurityMonitoringRuleMaxSignalDuration,
)
from datadog_api_client.v2.model.security_monitoring_rule_options import SecurityMonitoringRuleOptions
from datadog_api_client.v2.model.security_monitoring_rule_query_aggregation import (
    SecurityMonitoringRuleQueryAggregation,
)
from datadog_api_client.v2.model.security_monitoring_rule_severity import SecurityMonitoringRuleSeverity
from datadog_api_client.v2.model.security_monitoring_signal_rule_create_payload import (
    SecurityMonitoringSignalRuleCreatePayload,
)
from datadog_api_client.v2.model.security_monitoring_signal_rule_query import SecurityMonitoringSignalRuleQuery
from datadog_api_client.v2.model.security_monitoring_signal_rule_type import SecurityMonitoringSignalRuleType

# there is a valid "security_rule" in the system
SECURITY_RULE_ID = environ["SECURITY_RULE_ID"]

# there is a valid "security_rule_bis" in the system
SECURITY_RULE_BIS_ID = environ["SECURITY_RULE_BIS_ID"]

body = SecurityMonitoringSignalRuleCreatePayload(
    name="Example-Create_a_detection_rule_with_type_signal_correlation_returns_OK_response_signal_rule",
    queries=[
        SecurityMonitoringSignalRuleQuery(
            rule_id=SECURITY_RULE_ID,
            aggregation=SecurityMonitoringRuleQueryAggregation.EVENT_COUNT,
            correlated_by_fields=[
                "host",
            ],
            correlated_query_index=1,
        ),
        SecurityMonitoringSignalRuleQuery(
            rule_id=SECURITY_RULE_BIS_ID,
            aggregation=SecurityMonitoringRuleQueryAggregation.EVENT_COUNT,
            correlated_by_fields=[
                "host",
            ],
        ),
    ],
    filters=[],
    cases=[
        SecurityMonitoringRuleCaseCreate(
            name="",
            status=SecurityMonitoringRuleSeverity.INFO,
            condition="a > 0 && b > 0",
            notifications=[],
        ),
    ],
    options=SecurityMonitoringRuleOptions(
        evaluation_window=SecurityMonitoringRuleEvaluationWindow.FIFTEEN_MINUTES,
        keep_alive=SecurityMonitoringRuleKeepAlive.ONE_HOUR,
        max_signal_duration=SecurityMonitoringRuleMaxSignalDuration.ONE_DAY,
    ),
    message="Test signal correlation rule",
    tags=[],
    is_enabled=True,
    type=SecurityMonitoringSignalRuleType.SIGNAL_CORRELATION,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    response = api_instance.create_security_monitoring_rule(body=body)

    print(response)



"""
Get a list of pipelines events returns "OK" response with pagination
"""

from datetime import datetime
from dateutil.relativedelta import relativedelta
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.ci_visibility_pipelines_api import CIVisibilityPipelinesApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = CIVisibilityPipelinesApi(api_client)
    items = api_instance.list_ci_app_pipeline_events_with_pagination(
        filter_from=(datetime.now() + relativedelta(seconds=-30)),
        filter_to=datetime.now(),
        page_limit=2,
    )
    for item in items:
        print(item)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class ScatterplotDimension(ModelSimple):
    """
    Dimension of the Scatterplot.

    :param value: Must be one of ["x", "y", "radius", "color"].
    :type value: str
    """

    allowed_values = {
        "x",
        "y",
        "radius",
        "color",
    }
    X: ClassVar["ScatterplotDimension"]
    Y: ClassVar["ScatterplotDimension"]
    RADIUS: ClassVar["ScatterplotDimension"]
    COLOR: ClassVar["ScatterplotDimension"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


ScatterplotDimension.X = ScatterplotDimension("x")
ScatterplotDimension.Y = ScatterplotDimension("y")
ScatterplotDimension.RADIUS = ScatterplotDimension("radius")
ScatterplotDimension.COLOR = ScatterplotDimension("color")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class MonitorRenotifyStatusType(ModelSimple):
    """
    The different statuses for which renotification is supported.

    :param value: Must be one of ["alert", "warn", "no data"].
    :type value: str
    """

    allowed_values = {
        "alert",
        "warn",
        "no data",
    }
    ALERT: ClassVar["MonitorRenotifyStatusType"]
    WARN: ClassVar["MonitorRenotifyStatusType"]
    NO_DATA: ClassVar["MonitorRenotifyStatusType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


MonitorRenotifyStatusType.ALERT = MonitorRenotifyStatusType("alert")
MonitorRenotifyStatusType.WARN = MonitorRenotifyStatusType("warn")
MonitorRenotifyStatusType.NO_DATA = MonitorRenotifyStatusType("no data")



"""
Get all SLOs returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.service_level_objectives_api import ServiceLevelObjectivesApi

# there is a valid "slo" in the system
SLO_DATA_0_ID = environ["SLO_DATA_0_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceLevelObjectivesApi(api_client)
    response = api_instance.list_slos(
        ids=SLO_DATA_0_ID,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v2.model.logs_metrics_response import LogsMetricsResponse
from datadog_api_client.v2.model.logs_metric_response import LogsMetricResponse
from datadog_api_client.v2.model.logs_metric_create_request import LogsMetricCreateRequest
from datadog_api_client.v2.model.logs_metric_update_request import LogsMetricUpdateRequest


class LogsMetricsApi:
    """
    Manage configuration of `log-based metrics <https://app.datadoghq.com/logs/pipelines/generate-metrics>`_ for your organization.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_logs_metric_endpoint = _Endpoint(
            settings={
                "response_type": (LogsMetricResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/config/metrics",
                "operation_id": "create_logs_metric",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (LogsMetricCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_logs_metric_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/config/metrics/{metric_id}",
                "operation_id": "delete_logs_metric",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "metric_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "metric_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_logs_metric_endpoint = _Endpoint(
            settings={
                "response_type": (LogsMetricResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/logs/config/metrics/{metric_id}",
                "operation_id": "get_logs_metric",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "metric_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "metric_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_logs_metrics_endpoint = _Endpoint(
            settings={
                "response_type": (LogsMetricsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/logs/config/metrics",
                "operation_id": "list_logs_metrics",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_logs_metric_endpoint = _Endpoint(
            settings={
                "response_type": (LogsMetricResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/config/metrics/{metric_id}",
                "operation_id": "update_logs_metric",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "metric_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "metric_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (LogsMetricUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_logs_metric(
        self,
        body: LogsMetricCreateRequest,
    ) -> LogsMetricResponse:
        """Create a log-based metric.

        Create a metric based on your ingested logs in your organization.
        Returns the log-based metric object from the request body when the request is successful.

        :param body: The definition of the new log-based metric.
        :type body: LogsMetricCreateRequest
        :rtype: LogsMetricResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_logs_metric_endpoint.call_with_http_info(**kwargs)

    def delete_logs_metric(
        self,
        metric_id: str,
    ) -> None:
        """Delete a log-based metric.

        Delete a specific log-based metric from your organization.

        :param metric_id: The name of the log-based metric.
        :type metric_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["metric_id"] = metric_id

        return self._delete_logs_metric_endpoint.call_with_http_info(**kwargs)

    def get_logs_metric(
        self,
        metric_id: str,
    ) -> LogsMetricResponse:
        """Get a log-based metric.

        Get a specific log-based metric from your organization.

        :param metric_id: The name of the log-based metric.
        :type metric_id: str
        :rtype: LogsMetricResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["metric_id"] = metric_id

        return self._get_logs_metric_endpoint.call_with_http_info(**kwargs)

    def list_logs_metrics(
        self,
    ) -> LogsMetricsResponse:
        """Get all log-based metrics.

        Get the list of configured log-based metrics with their definitions.

        :rtype: LogsMetricsResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_logs_metrics_endpoint.call_with_http_info(**kwargs)

    def update_logs_metric(
        self,
        metric_id: str,
        body: LogsMetricUpdateRequest,
    ) -> LogsMetricResponse:
        """Update a log-based metric.

        Update a specific log-based metric from your organization.
        Returns the log-based metric object from the request body when the request is successful.

        :param metric_id: The name of the log-based metric.
        :type metric_id: str
        :param body: New definition of the log-based metric.
        :type body: LogsMetricUpdateRequest
        :rtype: LogsMetricResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["metric_id"] = metric_id

        kwargs["body"] = body

        return self._update_logs_metric_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SensitiveDataScannerProduct(ModelSimple):
    """
    Datadog product onto which Sensitive Data Scanner can be activated.

    :param value: If omitted defaults to "logs". Must be one of ["logs", "rum", "events", "apm"].
    :type value: str
    """

    allowed_values = {
        "logs",
        "rum",
        "events",
        "apm",
    }
    LOGS: ClassVar["SensitiveDataScannerProduct"]
    RUM: ClassVar["SensitiveDataScannerProduct"]
    EVENTS: ClassVar["SensitiveDataScannerProduct"]
    APM: ClassVar["SensitiveDataScannerProduct"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SensitiveDataScannerProduct.LOGS = SensitiveDataScannerProduct("logs")
SensitiveDataScannerProduct.RUM = SensitiveDataScannerProduct("rum")
SensitiveDataScannerProduct.EVENTS = SensitiveDataScannerProduct("events")
SensitiveDataScannerProduct.APM = SensitiveDataScannerProduct("apm")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetAggregator(ModelSimple):
    """
    Aggregator used for the request.

    :param value: Must be one of ["avg", "last", "max", "min", "sum", "percentile"].
    :type value: str
    """

    allowed_values = {
        "avg",
        "last",
        "max",
        "min",
        "sum",
        "percentile",
    }
    AVERAGE: ClassVar["WidgetAggregator"]
    LAST: ClassVar["WidgetAggregator"]
    MAXIMUM: ClassVar["WidgetAggregator"]
    MINIMUM: ClassVar["WidgetAggregator"]
    SUM: ClassVar["WidgetAggregator"]
    PERCENTILE: ClassVar["WidgetAggregator"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetAggregator.AVERAGE = WidgetAggregator("avg")
WidgetAggregator.LAST = WidgetAggregator("last")
WidgetAggregator.MAXIMUM = WidgetAggregator("max")
WidgetAggregator.MINIMUM = WidgetAggregator("min")
WidgetAggregator.SUM = WidgetAggregator("sum")
WidgetAggregator.PERCENTILE = WidgetAggregator("percentile")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.table_widget_cell_display_mode import TableWidgetCellDisplayMode
    from datadog_api_client.v1.model.widget_sort import WidgetSort


class ApmStatsQueryColumnType(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.table_widget_cell_display_mode import TableWidgetCellDisplayMode
        from datadog_api_client.v1.model.widget_sort import WidgetSort

        return {
            "alias": (str,),
            "cell_display_mode": (TableWidgetCellDisplayMode,),
            "name": (str,),
            "order": (WidgetSort,),
        }

    attribute_map = {
        "alias": "alias",
        "cell_display_mode": "cell_display_mode",
        "name": "name",
        "order": "order",
    }

    def __init__(
        self_,
        name: str,
        alias: Union[str, UnsetType] = unset,
        cell_display_mode: Union[TableWidgetCellDisplayMode, UnsetType] = unset,
        order: Union[WidgetSort, UnsetType] = unset,
        **kwargs,
    ):
        """
        Column properties.

        :param alias: A user-assigned alias for the column.
        :type alias: str, optional

        :param cell_display_mode: Define a display mode for the table cell.
        :type cell_display_mode: TableWidgetCellDisplayMode, optional

        :param name: Column name.
        :type name: str

        :param order: Widget sorting methods.
        :type order: WidgetSort, optional
        """
        if alias is not unset:
            kwargs["alias"] = alias
        if cell_display_mode is not unset:
            kwargs["cell_display_mode"] = cell_display_mode
        if order is not unset:
            kwargs["order"] = order
        super().__init__(kwargs)

        self_.name = name



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_line_type import WidgetLineType
    from datadog_api_client.v1.model.widget_line_width import WidgetLineWidth


class WidgetRequestStyle(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_line_type import WidgetLineType
        from datadog_api_client.v1.model.widget_line_width import WidgetLineWidth

        return {
            "line_type": (WidgetLineType,),
            "line_width": (WidgetLineWidth,),
            "palette": (str,),
        }

    attribute_map = {
        "line_type": "line_type",
        "line_width": "line_width",
        "palette": "palette",
    }

    def __init__(
        self_,
        line_type: Union[WidgetLineType, UnsetType] = unset,
        line_width: Union[WidgetLineWidth, UnsetType] = unset,
        palette: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Define request widget style.

        :param line_type: Type of lines displayed.
        :type line_type: WidgetLineType, optional

        :param line_width: Width of line displayed.
        :type line_width: WidgetLineWidth, optional

        :param palette: Color palette to apply to the widget.
        :type palette: str, optional
        """
        if line_type is not unset:
            kwargs["line_type"] = line_type
        if line_width is not unset:
            kwargs["line_width"] = line_width
        if palette is not unset:
            kwargs["palette"] = palette
        super().__init__(kwargs)



"""
Delete a security filter returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    api_instance.delete_security_filter(
        security_filter_id="security_filter_id",
    )



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsTestDetailsSubType(ModelSimple):
    """
    The subtype of the Synthetic API test, `http`, `ssl`, `tcp`,
        `dns`, `icmp`, `udp`, `websocket`, `grpc` or `multi`.

    :param value: Must be one of ["http", "ssl", "tcp", "dns", "multi", "icmp", "udp", "websocket", "grpc"].
    :type value: str
    """

    allowed_values = {
        "http",
        "ssl",
        "tcp",
        "dns",
        "multi",
        "icmp",
        "udp",
        "websocket",
        "grpc",
    }
    HTTP: ClassVar["SyntheticsTestDetailsSubType"]
    SSL: ClassVar["SyntheticsTestDetailsSubType"]
    TCP: ClassVar["SyntheticsTestDetailsSubType"]
    DNS: ClassVar["SyntheticsTestDetailsSubType"]
    MULTI: ClassVar["SyntheticsTestDetailsSubType"]
    ICMP: ClassVar["SyntheticsTestDetailsSubType"]
    UDP: ClassVar["SyntheticsTestDetailsSubType"]
    WEBSOCKET: ClassVar["SyntheticsTestDetailsSubType"]
    GRPC: ClassVar["SyntheticsTestDetailsSubType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsTestDetailsSubType.HTTP = SyntheticsTestDetailsSubType("http")
SyntheticsTestDetailsSubType.SSL = SyntheticsTestDetailsSubType("ssl")
SyntheticsTestDetailsSubType.TCP = SyntheticsTestDetailsSubType("tcp")
SyntheticsTestDetailsSubType.DNS = SyntheticsTestDetailsSubType("dns")
SyntheticsTestDetailsSubType.MULTI = SyntheticsTestDetailsSubType("multi")
SyntheticsTestDetailsSubType.ICMP = SyntheticsTestDetailsSubType("icmp")
SyntheticsTestDetailsSubType.UDP = SyntheticsTestDetailsSubType("udp")
SyntheticsTestDetailsSubType.WEBSOCKET = SyntheticsTestDetailsSubType("websocket")
SyntheticsTestDetailsSubType.GRPC = SyntheticsTestDetailsSubType("grpc")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

import collections
from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    datetime,
    set_attribute_from_path,
    get_attribute_from_path,
    UnsetType,
    unset,
)
from datadog_api_client.v2.model.ci_app_tests_analytics_aggregate_response import CIAppTestsAnalyticsAggregateResponse
from datadog_api_client.v2.model.ci_app_tests_aggregate_request import CIAppTestsAggregateRequest
from datadog_api_client.v2.model.ci_app_test_events_response import CIAppTestEventsResponse
from datadog_api_client.v2.model.ci_app_sort import CIAppSort
from datadog_api_client.v2.model.ci_app_test_event import CIAppTestEvent
from datadog_api_client.v2.model.ci_app_test_events_request import CIAppTestEventsRequest


class CIVisibilityTestsApi:
    """
    Search or aggregate your CI Visibility test events over HTTP.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._aggregate_ci_app_test_events_endpoint = _Endpoint(
            settings={
                "response_type": (CIAppTestsAnalyticsAggregateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/ci/tests/analytics/aggregate",
                "operation_id": "aggregate_ci_app_test_events",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (CIAppTestsAggregateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._list_ci_app_test_events_endpoint = _Endpoint(
            settings={
                "response_type": (CIAppTestEventsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/ci/tests/events",
                "operation_id": "list_ci_app_test_events",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "filter_query": {
                    "openapi_types": (str,),
                    "attribute": "filter[query]",
                    "location": "query",
                },
                "filter_from": {
                    "openapi_types": (datetime,),
                    "attribute": "filter[from]",
                    "location": "query",
                },
                "filter_to": {
                    "openapi_types": (datetime,),
                    "attribute": "filter[to]",
                    "location": "query",
                },
                "sort": {
                    "openapi_types": (CIAppSort,),
                    "attribute": "sort",
                    "location": "query",
                },
                "page_cursor": {
                    "openapi_types": (str,),
                    "attribute": "page[cursor]",
                    "location": "query",
                },
                "page_limit": {
                    "validation": {
                        "inclusive_maximum": 1000,
                    },
                    "openapi_types": (int,),
                    "attribute": "page[limit]",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._search_ci_app_test_events_endpoint = _Endpoint(
            settings={
                "response_type": (CIAppTestEventsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/ci/tests/events/search",
                "operation_id": "search_ci_app_test_events",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "openapi_types": (CIAppTestEventsRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def aggregate_ci_app_test_events(
        self,
        body: CIAppTestsAggregateRequest,
    ) -> CIAppTestsAnalyticsAggregateResponse:
        """Aggregate tests events.

        The API endpoint to aggregate CI Visibility test events into buckets of computed metrics and timeseries.

        :type body: CIAppTestsAggregateRequest
        :rtype: CIAppTestsAnalyticsAggregateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._aggregate_ci_app_test_events_endpoint.call_with_http_info(**kwargs)

    def list_ci_app_test_events(
        self,
        *,
        filter_query: Union[str, UnsetType] = unset,
        filter_from: Union[datetime, UnsetType] = unset,
        filter_to: Union[datetime, UnsetType] = unset,
        sort: Union[CIAppSort, UnsetType] = unset,
        page_cursor: Union[str, UnsetType] = unset,
        page_limit: Union[int, UnsetType] = unset,
    ) -> CIAppTestEventsResponse:
        """Get a list of tests events.

        List endpoint returns CI Visibility test events that match a log search query.
        `Results are paginated similarly to logs <https://docs.datadoghq.com/logs/guide/collect-multiple-logs-with-pagination>`_.

        Use this endpoint to see your latest test events.

        :param filter_query: Search query following log syntax.
        :type filter_query: str, optional
        :param filter_from: Minimum timestamp for requested events.
        :type filter_from: datetime, optional
        :param filter_to: Maximum timestamp for requested events.
        :type filter_to: datetime, optional
        :param sort: Order of events in results.
        :type sort: CIAppSort, optional
        :param page_cursor: List following results with a cursor provided in the previous query.
        :type page_cursor: str, optional
        :param page_limit: Maximum number of events in the response.
        :type page_limit: int, optional
        :rtype: CIAppTestEventsResponse
        """
        kwargs: Dict[str, Any] = {}
        if filter_query is not unset:
            kwargs["filter_query"] = filter_query

        if filter_from is not unset:
            kwargs["filter_from"] = filter_from

        if filter_to is not unset:
            kwargs["filter_to"] = filter_to

        if sort is not unset:
            kwargs["sort"] = sort

        if page_cursor is not unset:
            kwargs["page_cursor"] = page_cursor

        if page_limit is not unset:
            kwargs["page_limit"] = page_limit

        return self._list_ci_app_test_events_endpoint.call_with_http_info(**kwargs)

    def list_ci_app_test_events_with_pagination(
        self,
        *,
        filter_query: Union[str, UnsetType] = unset,
        filter_from: Union[datetime, UnsetType] = unset,
        filter_to: Union[datetime, UnsetType] = unset,
        sort: Union[CIAppSort, UnsetType] = unset,
        page_cursor: Union[str, UnsetType] = unset,
        page_limit: Union[int, UnsetType] = unset,
    ) -> collections.abc.Iterable[CIAppTestEvent]:
        """Get a list of tests events.

        Provide a paginated version of :meth:`list_ci_app_test_events`, returning all items.

        :param filter_query: Search query following log syntax.
        :type filter_query: str, optional
        :param filter_from: Minimum timestamp for requested events.
        :type filter_from: datetime, optional
        :param filter_to: Maximum timestamp for requested events.
        :type filter_to: datetime, optional
        :param sort: Order of events in results.
        :type sort: CIAppSort, optional
        :param page_cursor: List following results with a cursor provided in the previous query.
        :type page_cursor: str, optional
        :param page_limit: Maximum number of events in the response.
        :type page_limit: int, optional

        :return: A generator of paginated results.
        :rtype: collections.abc.Iterable[CIAppTestEvent]
        """
        kwargs: Dict[str, Any] = {}
        if filter_query is not unset:
            kwargs["filter_query"] = filter_query

        if filter_from is not unset:
            kwargs["filter_from"] = filter_from

        if filter_to is not unset:
            kwargs["filter_to"] = filter_to

        if sort is not unset:
            kwargs["sort"] = sort

        if page_cursor is not unset:
            kwargs["page_cursor"] = page_cursor

        if page_limit is not unset:
            kwargs["page_limit"] = page_limit

        local_page_size = get_attribute_from_path(kwargs, "page_limit", 10)
        endpoint = self._list_ci_app_test_events_endpoint
        set_attribute_from_path(kwargs, "page_limit", local_page_size, endpoint.params_map)
        while True:
            response = endpoint.call_with_http_info(**kwargs)
            for item in get_attribute_from_path(response, "data"):
                yield item
            if len(get_attribute_from_path(response, "data")) < local_page_size:
                break
            set_attribute_from_path(
                kwargs, "page_cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
            )

    def search_ci_app_test_events(
        self,
        *,
        body: Union[CIAppTestEventsRequest, UnsetType] = unset,
    ) -> CIAppTestEventsResponse:
        """Search tests events.

        List endpoint returns CI Visibility test events that match a log search query.
        `Results are paginated similarly to logs <https://docs.datadoghq.com/logs/guide/collect-multiple-logs-with-pagination>`_.

        Use this endpoint to build complex events filtering and search.

        :type body: CIAppTestEventsRequest, optional
        :rtype: CIAppTestEventsResponse
        """
        kwargs: Dict[str, Any] = {}
        if body is not unset:
            kwargs["body"] = body

        return self._search_ci_app_test_events_endpoint.call_with_http_info(**kwargs)

    def search_ci_app_test_events_with_pagination(
        self,
        *,
        body: Union[CIAppTestEventsRequest, UnsetType] = unset,
    ) -> collections.abc.Iterable[CIAppTestEvent]:
        """Search tests events.

        Provide a paginated version of :meth:`search_ci_app_test_events`, returning all items.

        :type body: CIAppTestEventsRequest, optional

        :return: A generator of paginated results.
        :rtype: collections.abc.Iterable[CIAppTestEvent]
        """
        kwargs: Dict[str, Any] = {}
        if body is not unset:
            kwargs["body"] = body

        local_page_size = get_attribute_from_path(kwargs, "body.page.limit", 10)
        endpoint = self._search_ci_app_test_events_endpoint
        set_attribute_from_path(kwargs, "body.page.limit", local_page_size, endpoint.params_map)
        while True:
            response = endpoint.call_with_http_info(**kwargs)
            for item in get_attribute_from_path(response, "data"):
                yield item
            if len(get_attribute_from_path(response, "data")) < local_page_size:
                break
            set_attribute_from_path(
                kwargs, "body.page.cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
            )



"""
Delete an SLO correction returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.service_level_objective_corrections_api import ServiceLevelObjectiveCorrectionsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceLevelObjectiveCorrectionsApi(api_client)
    api_instance.delete_slo_correction(
        slo_correction_id="slo_correction_id",
    )



"""
Set an AWS tag filter returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.aws_integration_api import AWSIntegrationApi
from datadog_api_client.v1.model.aws_namespace import AWSNamespace
from datadog_api_client.v1.model.aws_tag_filter_create_request import AWSTagFilterCreateRequest

body = AWSTagFilterCreateRequest(
    account_id="1234567",
    namespace=AWSNamespace.ELB,
    tag_filter_str="prod*",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = AWSIntegrationApi(api_client)
    response = api_instance.create_aws_tag_filter(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class AzureAccount(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "automute": (bool,),
            "client_id": (str,),
            "client_secret": (str,),
            "errors": ([str],),
            "host_filters": (str,),
            "new_client_id": (str,),
            "new_tenant_name": (str,),
            "tenant_name": (str,),
        }

    attribute_map = {
        "automute": "automute",
        "client_id": "client_id",
        "client_secret": "client_secret",
        "errors": "errors",
        "host_filters": "host_filters",
        "new_client_id": "new_client_id",
        "new_tenant_name": "new_tenant_name",
        "tenant_name": "tenant_name",
    }

    def __init__(
        self_,
        automute: Union[bool, UnsetType] = unset,
        client_id: Union[str, UnsetType] = unset,
        client_secret: Union[str, UnsetType] = unset,
        errors: Union[List[str], UnsetType] = unset,
        host_filters: Union[str, UnsetType] = unset,
        new_client_id: Union[str, UnsetType] = unset,
        new_tenant_name: Union[str, UnsetType] = unset,
        tenant_name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Datadog-Azure integrations configured for your organization.

        :param automute: Silence monitors for expected Azure VM shutdowns.
        :type automute: bool, optional

        :param client_id: Your Azure web application ID.
        :type client_id: str, optional

        :param client_secret: Your Azure web application secret key.
        :type client_secret: str, optional

        :param errors: Errors in your configuration.
        :type errors: [str], optional

        :param host_filters: Limit the Azure instances that are pulled into Datadog by using tags.
            Only hosts that match one of the defined tags are imported into Datadog.
        :type host_filters: str, optional

        :param new_client_id: Your New Azure web application ID.
        :type new_client_id: str, optional

        :param new_tenant_name: Your New Azure Active Directory ID.
        :type new_tenant_name: str, optional

        :param tenant_name: Your Azure Active Directory ID.
        :type tenant_name: str, optional
        """
        if automute is not unset:
            kwargs["automute"] = automute
        if client_id is not unset:
            kwargs["client_id"] = client_id
        if client_secret is not unset:
            kwargs["client_secret"] = client_secret
        if errors is not unset:
            kwargs["errors"] = errors
        if host_filters is not unset:
            kwargs["host_filters"] = host_filters
        if new_client_id is not unset:
            kwargs["new_client_id"] = new_client_id
        if new_tenant_name is not unset:
            kwargs["new_tenant_name"] = new_tenant_name
        if tenant_name is not unset:
            kwargs["tenant_name"] = tenant_name
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.apm_stats_query_column_type import ApmStatsQueryColumnType
    from datadog_api_client.v1.model.apm_stats_query_row_type import ApmStatsQueryRowType


class ApmStatsQueryDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.apm_stats_query_column_type import ApmStatsQueryColumnType
        from datadog_api_client.v1.model.apm_stats_query_row_type import ApmStatsQueryRowType

        return {
            "columns": ([ApmStatsQueryColumnType],),
            "env": (str,),
            "name": (str,),
            "primary_tag": (str,),
            "resource": (str,),
            "row_type": (ApmStatsQueryRowType,),
            "service": (str,),
        }

    attribute_map = {
        "columns": "columns",
        "env": "env",
        "name": "name",
        "primary_tag": "primary_tag",
        "resource": "resource",
        "row_type": "row_type",
        "service": "service",
    }

    def __init__(
        self_,
        env: str,
        name: str,
        primary_tag: str,
        row_type: ApmStatsQueryRowType,
        service: str,
        columns: Union[List[ApmStatsQueryColumnType], UnsetType] = unset,
        resource: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The APM stats query for table and distributions widgets.

        :param columns: Column properties used by the front end for display.
        :type columns: [ApmStatsQueryColumnType], optional

        :param env: Environment name.
        :type env: str

        :param name: Operation name associated with service.
        :type name: str

        :param primary_tag: The organization's host group name and value.
        :type primary_tag: str

        :param resource: Resource name.
        :type resource: str, optional

        :param row_type: The level of detail for the request.
        :type row_type: ApmStatsQueryRowType

        :param service: Service name.
        :type service: str
        """
        if columns is not unset:
            kwargs["columns"] = columns
        if resource is not unset:
            kwargs["resource"] = resource
        super().__init__(kwargs)

        self_.env = env
        self_.name = name
        self_.primary_tag = primary_tag
        self_.row_type = row_type
        self_.service = service



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.events_group_by_sort import EventsGroupBySort


class EventsGroupBy(ModelNormal):
    validations = {
        "limit": {
            "inclusive_maximum": 2147483647,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.events_group_by_sort import EventsGroupBySort

        return {
            "facet": (str,),
            "limit": (int,),
            "sort": (EventsGroupBySort,),
        }

    attribute_map = {
        "facet": "facet",
        "limit": "limit",
        "sort": "sort",
    }

    def __init__(
        self_,
        facet: str,
        limit: Union[int, UnsetType] = unset,
        sort: Union[EventsGroupBySort, UnsetType] = unset,
        **kwargs,
    ):
        """
        A dimension on which to split a query's results.

        :param facet: The facet by which to split groups.
        :type facet: str

        :param limit: The maximum number of groups to return.
        :type limit: int, optional

        :param sort: The dimension by which to sort a query's results.
        :type sort: EventsGroupBySort, optional
        """
        if limit is not unset:
            kwargs["limit"] = limit
        if sort is not unset:
            kwargs["sort"] = sort
        super().__init__(kwargs)

        self_.facet = facet



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.monitor_group_search_response_counts import MonitorGroupSearchResponseCounts
    from datadog_api_client.v1.model.monitor_group_search_result import MonitorGroupSearchResult
    from datadog_api_client.v1.model.monitor_search_response_metadata import MonitorSearchResponseMetadata


class MonitorGroupSearchResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.monitor_group_search_response_counts import MonitorGroupSearchResponseCounts
        from datadog_api_client.v1.model.monitor_group_search_result import MonitorGroupSearchResult
        from datadog_api_client.v1.model.monitor_search_response_metadata import MonitorSearchResponseMetadata

        return {
            "counts": (MonitorGroupSearchResponseCounts,),
            "groups": ([MonitorGroupSearchResult],),
            "metadata": (MonitorSearchResponseMetadata,),
        }

    attribute_map = {
        "counts": "counts",
        "groups": "groups",
        "metadata": "metadata",
    }
    read_only_vars = {
        "counts",
        "groups",
    }

    def __init__(
        self_,
        counts: Union[MonitorGroupSearchResponseCounts, UnsetType] = unset,
        groups: Union[List[MonitorGroupSearchResult], UnsetType] = unset,
        metadata: Union[MonitorSearchResponseMetadata, UnsetType] = unset,
        **kwargs,
    ):
        """
        The response of a monitor group search.

        :param counts: The counts of monitor groups per different criteria.
        :type counts: MonitorGroupSearchResponseCounts, optional

        :param groups: The list of found monitor groups.
        :type groups: [MonitorGroupSearchResult], optional

        :param metadata: Metadata about the response.
        :type metadata: MonitorSearchResponseMetadata, optional
        """
        if counts is not unset:
            kwargs["counts"] = counts
        if groups is not unset:
            kwargs["groups"] = groups
        if metadata is not unset:
            kwargs["metadata"] = metadata
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class RUMQueryPageOptions(ModelNormal):
    validations = {
        "limit": {
            "inclusive_maximum": 1000,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "cursor": (str,),
            "limit": (int,),
        }

    attribute_map = {
        "cursor": "cursor",
        "limit": "limit",
    }

    def __init__(self_, cursor: Union[str, UnsetType] = unset, limit: Union[int, UnsetType] = unset, **kwargs):
        """
        Paging attributes for listing events.

        :param cursor: List following results with a cursor provided in the previous query.
        :type cursor: str, optional

        :param limit: Maximum number of events in the response.
        :type limit: int, optional
        """
        if cursor is not unset:
            kwargs["cursor"] = cursor
        if limit is not unset:
            kwargs["limit"] = limit
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_global_variable_parser_type import SyntheticsGlobalVariableParserType


class SyntheticsVariableParser(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_global_variable_parser_type import (
            SyntheticsGlobalVariableParserType,
        )

        return {
            "type": (SyntheticsGlobalVariableParserType,),
            "value": (str,),
        }

    attribute_map = {
        "type": "type",
        "value": "value",
    }

    def __init__(self_, type: SyntheticsGlobalVariableParserType, value: Union[str, UnsetType] = unset, **kwargs):
        """
        Details of the parser to use for the global variable.

        :param type: Type of parser for a Synthetics global variable from a synthetics test.
        :type type: SyntheticsGlobalVariableParserType

        :param value: Regex or JSON path used for the parser. Not used with type ``raw``.
        :type value: str, optional
        """
        if value is not unset:
            kwargs["value"] = value
        super().__init__(kwargs)

        self_.type = type



"""
Search RUM events returns "OK" response with pagination
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.rum_api import RUMApi
from datadog_api_client.v2.model.rum_query_filter import RUMQueryFilter
from datadog_api_client.v2.model.rum_query_options import RUMQueryOptions
from datadog_api_client.v2.model.rum_query_page_options import RUMQueryPageOptions
from datadog_api_client.v2.model.rum_search_events_request import RUMSearchEventsRequest
from datadog_api_client.v2.model.rum_sort import RUMSort

body = RUMSearchEventsRequest(
    filter=RUMQueryFilter(
        _from="now-15m",
        query="@type:session AND @session.type:user",
        to="now",
    ),
    options=RUMQueryOptions(
        time_offset=0,
        timezone="GMT",
    ),
    page=RUMQueryPageOptions(
        limit=2,
    ),
    sort=RUMSort.TIMESTAMP_ASCENDING,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = RUMApi(api_client)
    items = api_instance.search_rum_events_with_pagination(body=body)
    for item in items:
        print(item)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_private_location_secrets_authentication import (
        SyntheticsPrivateLocationSecretsAuthentication,
    )
    from datadog_api_client.v1.model.synthetics_private_location_secrets_config_decryption import (
        SyntheticsPrivateLocationSecretsConfigDecryption,
    )


class SyntheticsPrivateLocationSecrets(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_private_location_secrets_authentication import (
            SyntheticsPrivateLocationSecretsAuthentication,
        )
        from datadog_api_client.v1.model.synthetics_private_location_secrets_config_decryption import (
            SyntheticsPrivateLocationSecretsConfigDecryption,
        )

        return {
            "authentication": (SyntheticsPrivateLocationSecretsAuthentication,),
            "config_decryption": (SyntheticsPrivateLocationSecretsConfigDecryption,),
        }

    attribute_map = {
        "authentication": "authentication",
        "config_decryption": "config_decryption",
    }

    def __init__(
        self_,
        authentication: Union[SyntheticsPrivateLocationSecretsAuthentication, UnsetType] = unset,
        config_decryption: Union[SyntheticsPrivateLocationSecretsConfigDecryption, UnsetType] = unset,
        **kwargs,
    ):
        """
        Secrets for the private location. Only present in the response when creating the private location.

        :param authentication: Authentication part of the secrets.
        :type authentication: SyntheticsPrivateLocationSecretsAuthentication, optional

        :param config_decryption: Private key for the private location.
        :type config_decryption: SyntheticsPrivateLocationSecretsConfigDecryption, optional
        """
        if authentication is not unset:
            kwargs["authentication"] = authentication
        if config_decryption is not unset:
            kwargs["config_decryption"] = config_decryption
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


class UsageRumUnitsHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "browser_rum_units": (int,),
            "mobile_rum_units": (int,),
            "org_name": (str,),
            "public_id": (str,),
            "rum_units": (int, none_type),
        }

    attribute_map = {
        "browser_rum_units": "browser_rum_units",
        "mobile_rum_units": "mobile_rum_units",
        "org_name": "org_name",
        "public_id": "public_id",
        "rum_units": "rum_units",
    }

    def __init__(
        self_,
        browser_rum_units: Union[int, UnsetType] = unset,
        mobile_rum_units: Union[int, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        rum_units: Union[int, none_type, UnsetType] = unset,
        **kwargs,
    ):
        """
        Number of RUM Units used for each hour for a given organization (data available as of November 1, 2021).

        :param browser_rum_units: The number of browser RUM units.
        :type browser_rum_units: int, optional

        :param mobile_rum_units: The number of mobile RUM units.
        :type mobile_rum_units: int, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param rum_units: Total RUM units across mobile and browser RUM.
        :type rum_units: int, none_type, optional
        """
        if browser_rum_units is not unset:
            kwargs["browser_rum_units"] = browser_rum_units
        if mobile_rum_units is not unset:
            kwargs["mobile_rum_units"] = mobile_rum_units
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if rum_units is not unset:
            kwargs["rum_units"] = rum_units
        super().__init__(kwargs)



import json

from datadog_api_client.configuration import Configuration
from datadog_api_client.model_utils import validate_and_convert_types, model_to_dict

from datadog_api_client.v1.model.synthetics_api_test import SyntheticsAPITest
from datadog_api_client.v1.model.synthetics_browser_test import SyntheticsBrowserTest
from datadog_api_client.v1.model.synthetics_assertion import SyntheticsAssertion
from datadog_api_client.v2.model.logs_aggregate_response import LogsAggregateResponse
from datadog_api_client.v2.model.logs_archive import LogsArchive
from datadog_api_client.v2.model.logs_archive_destination import LogsArchiveDestination
from datadog_api_client.v2.model.user_response import UserResponse


def test_unknown_nested_oneof_in_list():
    body = """{
        "status": "paused",
        "public_id": "jv7-wfd-kvt",
        "tags": [],
        "locations": [
            "pl:pl-kevin-y-6382df0d72d4588e1817f090b131541f"
        ],
        "message": "",
        "name": "Test on www.example.com",
        "monitor_id": 28558768,
        "type": "api",
        "created_at": "2021-01-12T10:11:40.802074+00:00",
        "modified_at": "2021-01-22T16:42:10.520384+00:00",
        "subtype": "http",
        "config": {
            "request": {
                "url": "https://www.example.com",
                "method": "GET",
                "timeout": 30
            },
            "assertions": [
                {
                    "operator": "lessThan",
                    "type": "responseTime",
                    "target": 1000
                },
                {
                    "operator": "is",
                    "type": "statusCode",
                    "target": 200
                },
                {
                    "operator": "A non existent operator",
                    "type": "body",
                    "target": {
                        "xPath": "//html/head/title",
                        "operator": "contains",
                        "targetValue": "Example"
                    }
                }
            ],
            "configVariables": []
        },
        "options": {
            "monitor_options": {
                "notify_audit": false,
                "locked": false,
                "include_tags": true,
                "new_host_delay": 300,
                "notify_no_data": false,
                "renotify_interval": 0
            },
            "retry": {
                "count": 0,
                "interval": 300
            },
            "min_location_failed": 1,
            "min_failure_duration": 0,
            "tick_every": 60
        }
    }"""
    config = Configuration()
    deserialized_data = validate_and_convert_types(
        json.loads(body), (SyntheticsAPITest,), ["received_data"], True, True, config
    )
    assert isinstance(deserialized_data, SyntheticsAPITest)
    assert len(deserialized_data.config.assertions) == 3
    assert deserialized_data.config.assertions[2].operator == "A non existent operator"
    assert deserialized_data.config.assertions[2]._composed_instances[0]._unparsed
    assert not deserialized_data.config.assertions[1]._composed_instances[0]._unparsed


def test_unknown_nested_enum_in_list():
    body = """{
        "status": "live",
        "public_id": "2fx-64b-fb8",
        "tags": [
            "mini-website",
            "team:synthetics",
            "firefox",
            "synthetics-ci-browser",
            "edge",
            "chrome"
        ],
        "locations": [
            "aws:ap-northeast-1",
            "aws:eu-north-1",
            "aws:eu-west-3",
            "aws:eu-central-1"
        ],
        "message": "This mini-website check failed, please investigate why. @slack-synthetics-ops-worker",
        "name": "Mini Website - Click Trap",
        "monitor_id": 7647262,
        "type": "browser",
        "created_at": "2018-12-20T13:19:23.734004+00:00",
        "modified_at": "2021-06-30T15:46:49.387631+00:00",
        "config": {
            "variables": [],
            "setCookie": "",
            "request": {
                "url": "http://34.95.79.70/click-trap",
                "headers": {},
                "method": "GET"
            },
            "assertions": [],
            "configVariables": []
        },
        "options": {
            "ci": {
                "executionRule": "blocking"
            },
            "retry": {
                "count": 1,
                "interval": 1000
            },
            "min_location_failed": 1,
            "min_failure_duration": 0,
            "noScreenshot": false,
            "tick_every": 300,
            "forwardProxy": false,
            "disableCors": false,
            "device_ids": [
                "chrome.laptop_large",
                "firefox.laptop_large",
                "A non existent device ID"
            ],
            "monitor_options": {
                "renotify_interval": 360
            },
            "ignoreServerCertificateError": true
        }
    }"""
    config = Configuration()
    deserialized_data = validate_and_convert_types(
        json.loads(body), (SyntheticsBrowserTest,), ["received_data"], True, True, config
    )
    assert isinstance(deserialized_data, SyntheticsBrowserTest)
    assert len(deserialized_data.options.device_ids) == 3
    assert str(deserialized_data.options.device_ids[2]) == "A non existent device ID"
    assert deserialized_data.options.device_ids[2]._unparsed


def test_unknown_top_level_enum():
    body = """{
        "status": "live",
        "public_id": "g6d-gcm-pdq",
        "tags": [],
        "locations": [
            "aws:eu-central-1",
            "aws:ap-northeast-1"
        ],
        "message": "",
        "name": "Check on www.10.0.0.1.xip.io",
        "monitor_id": 7464050,
        "type": "A non existent test type",
        "created_at": "2018-12-07T17:30:49.785089+00:00",
        "modified_at": "2019-09-04T17:01:09.921070+00:00",
        "subtype": "http",
        "config": {
            "request": {
                "url": "https://www.10.0.0.1.xip.io",
                "method": "GET",
                "timeout": 30
            },
            "assertions": [
                {
                    "operator": "is",
                    "type": "statusCode",
                    "target": 200
                }
            ]
        },
        "options": {
            "tick_every": 60
        }
    }"""
    config = Configuration()
    deserialized_data = validate_and_convert_types(
        json.loads(body), (SyntheticsBrowserTest,), ["received_data"], True, True, config
    )
    assert isinstance(deserialized_data, SyntheticsBrowserTest)
    assert str(deserialized_data.type) == "A non existent test type"


def test_unknown_nested_enum():
    body = """{
        "status": "live",
        "public_id": "g6d-gcm-pdq",
        "tags": [],
        "locations": [
            "aws:eu-central-1",
            "aws:ap-northeast-1"
        ],
        "message": "",
        "name": "Check on www.10.0.0.1.xip.io",
        "monitor_id": 7464050,
        "type": "api",
        "created_at": "2018-12-07T17:30:49.785089+00:00",
        "modified_at": "2019-09-04T17:01:09.921070+00:00",
        "subtype": "http",
        "config": {
            "request": {
                "url": "https://www.10.0.0.1.xip.io",
                "method": "GET",
                "timeout": 30
            },
            "assertions": [
                {
                    "operator": "not-an-operator",
                    "type": "statusCode",
                    "target": 200
                }
            ]
        },
        "options": {
            "tick_every": 60
        }
    }"""
    config = Configuration()
    deserialized_data = validate_and_convert_types(
        json.loads(body), (SyntheticsAPITest,), ["received_data"], True, True, config
    )
    assert isinstance(deserialized_data, SyntheticsAPITest)
    assert isinstance(deserialized_data.config.assertions[0], SyntheticsAssertion)
    assert str(deserialized_data.config.assertions[0].operator) == "not-an-operator"
    assert deserialized_data.config.assertions[0]._unparsed


def test_unknown_nested_one_of():
    body = """{
        "data": {
            "type": "archives",
            "id": "n_XDSxVpScepiBnyhysj_A",
            "attributes": {
                "name": "my first azure archive",
                "query": "service:toto",
                "state": "UNKNOWN",
                "destination": {
                    "container": "my-container",
                    "storage_account": "storageaccount",
                    "path": "/path/blou",
                    "type": "A non existent destination",
                    "integration": {
                        "tenant_id": "tf-TestAccDatadogLogsArchiveAzure_basic-local-1624981538",
                        "client_id": "testc7f6-1234-5678-9101-3fcbf464test"
                    }
                },
                "rehydration_tags": [],
                "include_tags": false
            }
        }
    }"""
    config = Configuration()
    deserialized_data = validate_and_convert_types(
        json.loads(body), (LogsArchive,), ["received_data"], True, True, config
    )
    assert isinstance(deserialized_data, LogsArchive)
    assert isinstance(deserialized_data.data.attributes.destination, LogsArchiveDestination)
    assert deserialized_data.data.attributes.destination.type == "A non existent destination"
    assert deserialized_data.data.attributes.destination._composed_instances[0]._unparsed


def test_one_of_primitive_types():
    body = """{"data": {"buckets": [{"by": {}, "computes": {"c0": 435.3}}]}}"""
    config = Configuration()
    deserialized_data = validate_and_convert_types(
        json.loads(body), (LogsAggregateResponse,), ["received_data"], True, True, config
    )
    assert isinstance(deserialized_data, LogsAggregateResponse)
    assert deserialized_data.data.buckets[0].computes["c0"] == 435.3


def test_unknown_model_value():
    body = """{
        "data": {
            "type": "users",
            "id": "6d716162-8b48-11ec-8120-da7ad0900002",
            "attributes": {
                "name": null,
                "created_at": "2022-02-11T14:39:33.168622+00:00",
                "modified_at": "2022-02-11T14:39:33.210204+00:00",
                "title": "user title",
                "verified": false,
                "service_account": false,
                "disabled": false,
                "allowed_login_methods": [],
                "status": "Pending"
            },
            "relationships": {
                "roles": { "data": [] },
                "org": {
                    "data": { "type": "orgs", "id": "4dee724d-00cc-11ea-a77b-570c9d03c6c5" }
                }
            }
        }
    }"""
    config = Configuration()
    deserialized_data = validate_and_convert_types(
        json.loads(body), (UserResponse,), ["received_data"], True, True, config
    )
    assert isinstance(deserialized_data, UserResponse)
    serialized = model_to_dict(deserialized_data)
    assert "allowed_login_methods" in serialized["data"]["attributes"]
    assert serialized["data"]["attributes"]["allowed_login_methods"] == []



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.heat_map_widget_definition import HeatMapWidgetDefinition
    from datadog_api_client.v1.model.notebook_graph_size import NotebookGraphSize
    from datadog_api_client.v1.model.notebook_split_by import NotebookSplitBy
    from datadog_api_client.v1.model.notebook_cell_time import NotebookCellTime
    from datadog_api_client.v1.model.notebook_relative_time import NotebookRelativeTime
    from datadog_api_client.v1.model.notebook_absolute_time import NotebookAbsoluteTime


class NotebookHeatMapCellAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.heat_map_widget_definition import HeatMapWidgetDefinition
        from datadog_api_client.v1.model.notebook_graph_size import NotebookGraphSize
        from datadog_api_client.v1.model.notebook_split_by import NotebookSplitBy
        from datadog_api_client.v1.model.notebook_cell_time import NotebookCellTime

        return {
            "definition": (HeatMapWidgetDefinition,),
            "graph_size": (NotebookGraphSize,),
            "split_by": (NotebookSplitBy,),
            "time": (NotebookCellTime,),
        }

    attribute_map = {
        "definition": "definition",
        "graph_size": "graph_size",
        "split_by": "split_by",
        "time": "time",
    }

    def __init__(
        self_,
        definition: HeatMapWidgetDefinition,
        graph_size: Union[NotebookGraphSize, UnsetType] = unset,
        split_by: Union[NotebookSplitBy, UnsetType] = unset,
        time: Union[Union[NotebookCellTime, NotebookRelativeTime, NotebookAbsoluteTime], none_type, UnsetType] = unset,
        **kwargs,
    ):
        """
        The attributes of a notebook ``heatmap`` cell.

        :param definition: The heat map visualization shows metrics aggregated across many tags, such as hosts. The more hosts that have a particular value, the darker that square is.
        :type definition: HeatMapWidgetDefinition

        :param graph_size: The size of the graph.
        :type graph_size: NotebookGraphSize, optional

        :param split_by: Object describing how to split the graph to display multiple visualizations per request.
        :type split_by: NotebookSplitBy, optional

        :param time: Timeframe for the notebook cell. When 'null', the notebook global time is used.
        :type time: NotebookCellTime, none_type, optional
        """
        if graph_size is not unset:
            kwargs["graph_size"] = graph_size
        if split_by is not unset:
            kwargs["split_by"] = split_by
        if time is not unset:
            kwargs["time"] = time
        super().__init__(kwargs)

        self_.definition = definition



"""
Create a new dashboard with apm_issue_stream list_stream widget
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.list_stream_column import ListStreamColumn
from datadog_api_client.v1.model.list_stream_column_width import ListStreamColumnWidth
from datadog_api_client.v1.model.list_stream_query import ListStreamQuery
from datadog_api_client.v1.model.list_stream_response_format import ListStreamResponseFormat
from datadog_api_client.v1.model.list_stream_source import ListStreamSource
from datadog_api_client.v1.model.list_stream_widget_definition import ListStreamWidgetDefinition
from datadog_api_client.v1.model.list_stream_widget_definition_type import ListStreamWidgetDefinitionType
from datadog_api_client.v1.model.list_stream_widget_request import ListStreamWidgetRequest
from datadog_api_client.v1.model.widget import Widget

body = Dashboard(
    layout_type=DashboardLayoutType.ORDERED,
    title="Example-Create_a_new_dashboard_with_apm_issue_stream_list_stream_widget with list_stream widget",
    widgets=[
        Widget(
            definition=ListStreamWidgetDefinition(
                type=ListStreamWidgetDefinitionType.LIST_STREAM,
                requests=[
                    ListStreamWidgetRequest(
                        columns=[
                            ListStreamColumn(
                                width=ListStreamColumnWidth.AUTO,
                                field="timestamp",
                            ),
                        ],
                        query=ListStreamQuery(
                            data_source=ListStreamSource.APM_ISSUE_STREAM,
                            query_string="",
                        ),
                        response_format=ListStreamResponseFormat.EVENT_LIST,
                    ),
                ],
            ),
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



"""
Create a user returns "User created" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.users_api import UsersApi
from datadog_api_client.v1.model.access_role import AccessRole
from datadog_api_client.v1.model.user import User

body = User(
    access_role=AccessRole.STANDARD,
    disabled=False,
    email="test@datadoghq.com",
    handle="test@datadoghq.com",
    name="test user",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = UsersApi(api_client)
    response = api_instance.create_user(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class OrganizationSettingsSamlAutocreateUsersDomains(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "domains": ([str],),
            "enabled": (bool,),
        }

    attribute_map = {
        "domains": "domains",
        "enabled": "enabled",
    }

    def __init__(
        self_, domains: Union[List[str], UnsetType] = unset, enabled: Union[bool, UnsetType] = unset, **kwargs
    ):
        """
        Has two properties, ``enabled`` (boolean) and ``domains`` , which is a list of domains without the @ symbol.

        :param domains: List of domains where the SAML automated user creation is enabled.
        :type domains: [str], optional

        :param enabled: Whether or not the automated user creation based on SAML domain is enabled.
        :type enabled: bool, optional
        """
        if domains is not unset:
            kwargs["domains"] = domains
        if enabled is not unset:
            kwargs["enabled"] = enabled
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.chargeback_breakdown import ChargebackBreakdown


class CostByOrgAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.chargeback_breakdown import ChargebackBreakdown

        return {
            "charges": ([ChargebackBreakdown],),
            "date": (datetime,),
            "org_name": (str,),
            "public_id": (str,),
            "total_cost": (float,),
        }

    attribute_map = {
        "charges": "charges",
        "date": "date",
        "org_name": "org_name",
        "public_id": "public_id",
        "total_cost": "total_cost",
    }

    def __init__(
        self_,
        charges: Union[List[ChargebackBreakdown], UnsetType] = unset,
        date: Union[datetime, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        total_cost: Union[float, UnsetType] = unset,
        **kwargs,
    ):
        """
        Cost attributes data.

        :param charges: List of charges data reported for the requested month.
        :type charges: [ChargebackBreakdown], optional

        :param date: The month requested.
        :type date: datetime, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param total_cost: The total cost of products for the month.
        :type total_cost: float, optional
        """
        if charges is not unset:
            kwargs["charges"] = charges
        if date is not unset:
            kwargs["date"] = date
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if total_cost is not unset:
            kwargs["total_cost"] = total_cost
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.incident_attachment_attributes import IncidentAttachmentAttributes
    from datadog_api_client.v2.model.incident_attachment_relationships import IncidentAttachmentRelationships
    from datadog_api_client.v2.model.incident_attachment_type import IncidentAttachmentType
    from datadog_api_client.v2.model.incident_attachment_postmortem_attributes import (
        IncidentAttachmentPostmortemAttributes,
    )
    from datadog_api_client.v2.model.incident_attachment_link_attributes import IncidentAttachmentLinkAttributes


class IncidentAttachmentData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.incident_attachment_attributes import IncidentAttachmentAttributes
        from datadog_api_client.v2.model.incident_attachment_relationships import IncidentAttachmentRelationships
        from datadog_api_client.v2.model.incident_attachment_type import IncidentAttachmentType

        return {
            "attributes": (IncidentAttachmentAttributes,),
            "id": (str,),
            "relationships": (IncidentAttachmentRelationships,),
            "type": (IncidentAttachmentType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "id": "id",
        "relationships": "relationships",
        "type": "type",
    }

    def __init__(
        self_,
        attributes: Union[
            IncidentAttachmentAttributes, IncidentAttachmentPostmortemAttributes, IncidentAttachmentLinkAttributes
        ],
        id: str,
        relationships: IncidentAttachmentRelationships,
        type: IncidentAttachmentType,
        **kwargs,
    ):
        """
        A single incident attachment.

        :param attributes: The attributes object for an attachment.
        :type attributes: IncidentAttachmentAttributes

        :param id: A unique identifier that represents the incident attachment.
        :type id: str

        :param relationships: The incident attachment's relationships.
        :type relationships: IncidentAttachmentRelationships

        :param type: The incident attachment resource type.
        :type type: IncidentAttachmentType
        """
        super().__init__(kwargs)

        self_.attributes = attributes
        self_.id = id
        self_.relationships = relationships
        self_.type = type



"""
Add Confluent account returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.confluent_cloud_api import ConfluentCloudApi
from datadog_api_client.v2.model.confluent_account_create_request import ConfluentAccountCreateRequest
from datadog_api_client.v2.model.confluent_account_create_request_attributes import (
    ConfluentAccountCreateRequestAttributes,
)
from datadog_api_client.v2.model.confluent_account_create_request_data import ConfluentAccountCreateRequestData
from datadog_api_client.v2.model.confluent_account_resource_attributes import ConfluentAccountResourceAttributes
from datadog_api_client.v2.model.confluent_account_type import ConfluentAccountType

body = ConfluentAccountCreateRequest(
    data=ConfluentAccountCreateRequestData(
        attributes=ConfluentAccountCreateRequestAttributes(
            api_key="TESTAPIKEY123",
            api_secret="test-api-secret-123",
            resources=[
                ConfluentAccountResourceAttributes(
                    id="resource-id-123",
                    resource_type="kafka",
                    tags=[
                        "myTag",
                        "myTag2:myValue",
                    ],
                ),
            ],
            tags=[
                "myTag",
                "myTag2:myValue",
            ],
        ),
        type=ConfluentAccountType.CONFLUENT_CLOUD_ACCOUNTS,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ConfluentCloudApi(api_client)
    response = api_instance.create_confluent_account(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetVerticalAlign(ModelSimple):
    """
    Vertical alignment.

    :param value: Must be one of ["center", "top", "bottom"].
    :type value: str
    """

    allowed_values = {
        "center",
        "top",
        "bottom",
    }
    CENTER: ClassVar["WidgetVerticalAlign"]
    TOP: ClassVar["WidgetVerticalAlign"]
    BOTTOM: ClassVar["WidgetVerticalAlign"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetVerticalAlign.CENTER = WidgetVerticalAlign("center")
WidgetVerticalAlign.TOP = WidgetVerticalAlign("top")
WidgetVerticalAlign.BOTTOM = WidgetVerticalAlign("bottom")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.security_monitoring_rule_query_aggregation import (
        SecurityMonitoringRuleQueryAggregation,
    )


class SecurityMonitoringSignalRuleResponseQuery(ModelNormal):
    validations = {
        "correlated_query_index": {
            "inclusive_maximum": 9,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.security_monitoring_rule_query_aggregation import (
            SecurityMonitoringRuleQueryAggregation,
        )

        return {
            "aggregation": (SecurityMonitoringRuleQueryAggregation,),
            "correlated_by_fields": ([str],),
            "correlated_query_index": (int,),
            "default_rule_id": (str,),
            "metrics": ([str],),
            "name": (str,),
            "rule_id": (str,),
        }

    attribute_map = {
        "aggregation": "aggregation",
        "correlated_by_fields": "correlatedByFields",
        "correlated_query_index": "correlatedQueryIndex",
        "default_rule_id": "defaultRuleId",
        "metrics": "metrics",
        "name": "name",
        "rule_id": "ruleId",
    }

    def __init__(
        self_,
        aggregation: Union[SecurityMonitoringRuleQueryAggregation, UnsetType] = unset,
        correlated_by_fields: Union[List[str], UnsetType] = unset,
        correlated_query_index: Union[int, UnsetType] = unset,
        default_rule_id: Union[str, UnsetType] = unset,
        metrics: Union[List[str], UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        rule_id: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Query for matching rule on signals.

        :param aggregation: The aggregation type.
        :type aggregation: SecurityMonitoringRuleQueryAggregation, optional

        :param correlated_by_fields: Fields to group by.
        :type correlated_by_fields: [str], optional

        :param correlated_query_index: Index of the rule query used to retrieve the correlated field.
        :type correlated_query_index: int, optional

        :param default_rule_id: Default Rule ID to match on signals.
        :type default_rule_id: str, optional

        :param metrics: Group of target fields to aggregate over.
        :type metrics: [str], optional

        :param name: Name of the query.
        :type name: str, optional

        :param rule_id: Rule ID to match on signals.
        :type rule_id: str, optional
        """
        if aggregation is not unset:
            kwargs["aggregation"] = aggregation
        if correlated_by_fields is not unset:
            kwargs["correlated_by_fields"] = correlated_by_fields
        if correlated_query_index is not unset:
            kwargs["correlated_query_index"] = correlated_query_index
        if default_rule_id is not unset:
            kwargs["default_rule_id"] = default_rule_id
        if metrics is not unset:
            kwargs["metrics"] = metrics
        if name is not unset:
            kwargs["name"] = name
        if rule_id is not unset:
            kwargs["rule_id"] = rule_id
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_grok_parser_rules import LogsGrokParserRules
    from datadog_api_client.v1.model.logs_grok_parser_type import LogsGrokParserType


class LogsGrokParser(ModelNormal):
    validations = {
        "samples": {
            "max_items": 5,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_grok_parser_rules import LogsGrokParserRules
        from datadog_api_client.v1.model.logs_grok_parser_type import LogsGrokParserType

        return {
            "grok": (LogsGrokParserRules,),
            "is_enabled": (bool,),
            "name": (str,),
            "samples": ([str],),
            "source": (str,),
            "type": (LogsGrokParserType,),
        }

    attribute_map = {
        "grok": "grok",
        "is_enabled": "is_enabled",
        "name": "name",
        "samples": "samples",
        "source": "source",
        "type": "type",
    }

    def __init__(
        self_,
        grok: LogsGrokParserRules,
        type: LogsGrokParserType,
        is_enabled: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        samples: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        Create custom grok rules to parse the full message or `a specific attribute of your raw event <https://docs.datadoghq.com/logs/log_configuration/parsing/#advanced-settings>`_.
        For more information, see the `parsing section <https://docs.datadoghq.com/logs/log_configuration/parsing>`_.

        :param grok: Set of rules for the grok parser.
        :type grok: LogsGrokParserRules

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param name: Name of the processor.
        :type name: str, optional

        :param samples: List of sample logs to test this grok parser.
        :type samples: [str], optional

        :param source: Name of the log attribute to parse.
        :type source: str

        :param type: Type of logs grok parser.
        :type type: LogsGrokParserType
        """
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if name is not unset:
            kwargs["name"] = name
        if samples is not unset:
            kwargs["samples"] = samples
        super().__init__(kwargs)
        source = kwargs.get("source", "message")

        self_.grok = grok
        self_.source = source
        self_.type = type
